# Tree

-   category: Components
-   family: DataDisplay
-   chinese: 树形控件
-   type: 基本

---

## 开发指南

### 何时使用

文件夹、组织架构、生物分类、国家地区等等，世间万物的大多数结构都是树形结构。使用`树控件`可以完整展现其中的层级关系，并具有展开收起选择等交互功能。

## API

### Tree

| 参数                  | 说明                                                                                                                                                                                                                                                                                                                                                                                                               | 类型                      | 默认值        |
| ------------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ----------------------- | ---------- |
| children            | 树节点                                                                                                                                                                                                                                                                                                                                                                                                              | ReactNode               | -          |
| dataSource          | 数据源，该属性优先级高于 children                                                                                                                                                                                                                                                                                                                                                                                            | Array                   | -          |
| showLine            | 是否显示树的线                                                                                                                                                                                                                                                                                                                                                                                                          | Boolean                 | false      |
| selectable          | 是否支持选中节点                                                                                                                                                                                                                                                                                                                                                                                                         | Boolean                 | true       |
| selectedKeys        | （用于受控）当前选中节点 key 的数组                                                                                                                                                                                                                                                                                                                                                                                             | Array&lt;String>        | -          |
| defaultSelectedKeys | （用于非受控）默认选中节点 key 的数组                                                                                                                                                                                                                                                                                                                                                                                            | Array&lt;String>        | \[]        |
| onSelect            | 选中或取消选中节点时触发的回调函数<br><br>**签名**:<br>Function(selectedKeys: Array, extra: Object) => void<br>**参数**:<br>_selectedKeys_: {Array} 选中节点key的数组<br>_extra_: {Object} 额外参数<br>_extra.selectedNodes_: {Array} 选中节点的数组<br>_extra.node_: {Object} 当前操作的节点<br>_extra.selected_: {Boolean} 当前操作是否是选中                                                                                                                         | Function                | func.noop  |
| multiple            | 是否支持多选                                                                                                                                                                                                                                                                                                                                                                                                           | Boolean                 | false      |
| checkable           | 是否支持勾选节点的复选框                                                                                                                                                                                                                                                                                                                                                                                                     | Boolean                 | false      |
| checkedKeys         | （用于受控）当前勾选复选框节点 key 的数组或 `{checked: Array, indeterminate: Array}` 的对象                                                                                                                                                                                                                                                                                                                                            | Array&lt;String>/Object | -          |
| defaultCheckedKeys  | （用于非受控）默认勾选复选框节点 key 的数组                                                                                                                                                                                                                                                                                                                                                                                         | Array&lt;String>        | \[]        |
| checkStrictly       | 勾选节点复选框是否完全受控（父子节点选中状态不再关联）                                                                                                                                                                                                                                                                                                                                                                                      | Boolean                 | false      |
| checkedStrategy     | 定义选中时回填的方式<br><br>**可选值**:<br>'all'(返回所有选中的节点)<br>'parent'(父子节点都选中时只返回父节点)<br>'child'(父子节点都选中时只返回子节点)                                                                                                                                                                                                                                                                                                            | Enum                    | 'all'      |
| onCheck             | 勾选或取消勾选复选框时触发的回调函数<br><br>**签名**:<br>Function(checkedKeys: Array, extra: Object) => void<br>**参数**:<br>_checkedKeys_: {Array} 勾选复选框节点key的数组<br>_extra_: {Object} 额外参数<br>_extra.checkedNodes_: {Array} 勾选复选框节点的数组<br>_extra.checkedNodesPositions_: {Array} 包含有勾选复选框节点和其位置的对象的数组<br>_extra.indeterminateKeys_: {Array} 半选复选框节点 key 的数组<br>_extra.node_: {Object} 当前操作的节点<br>_extra.checked_: {Boolean} 当前操作是否是勾选 | Function                | func.noop  |
| expandedKeys        | （用于受控）当前展开的节点 key 的数组                                                                                                                                                                                                                                                                                                                                                                                            | Array&lt;String>        | -          |
| defaultExpandedKeys | （用于非受控）默认展开的节点 key 的数组                                                                                                                                                                                                                                                                                                                                                                                           | Array&lt;String>        | \[]        |
| defaultExpandAll    | 是否默认展开所有节点                                                                                                                                                                                                                                                                                                                                                                                                       | Boolean                 | false      |
| autoExpandParent    | 是否自动展开父节点，建议受控时设置为false                                                                                                                                                                                                                                                                                                                                                                                          | Boolean                 | true       |
| onExpand            | 展开或收起节点时触发的回调函数<br><br>**签名**:<br>Function(expandedKeys: Array, extra: Object) => void<br>**参数**:<br>_expandedKeys_: {Array} 展开的节点key的数组<br>_extra_: {Object} 额外参数<br>_extra.node_: {Object} 当前操作的节点<br>_extra.expanded_: {Boolean} 当前操作是否是展开                                                                                                                                                                    | Function                | func.noop  |
| editable            | 是否支持编辑节点内容                                                                                                                                                                                                                                                                                                                                                                                                       | Boolean                 | false      |
| onEditFinish        | 编辑节点内容完成时触发的回调函数<br><br>**签名**:<br>Function(key: String, label: String, node: Object) => void<br>**参数**:<br>_key_: {String} 编辑节点的 key<br>_label_: {String} 编辑节点完成时节点的文本<br>_node_: {Object} 当前编辑的节点                                                                                                                                                                                                              | Function                | func.noop  |
| draggable           | 是否支持拖拽节点                                                                                                                                                                                                                                                                                                                                                                                                         | Boolean                 | false      |
| onDragStart         | 开始拖拽节点时触发的回调函数<br><br>**签名**:<br>Function(info: Object) => void<br>**参数**:<br>_info_: {Object} 拖拽信息<br>_info.event_: {Object} 事件对象<br>_info.node_: {Object} 拖拽的节点                                                                                                                                                                                                                                                | Function                | func.noop  |
| onDragEnter         | 拖拽节点进入目标节点时触发的回调函数<br><br>**签名**:<br>Function(info: Object) => void<br>**参数**:<br>_info_: {Object} 拖拽信息<br>_info.event_: {Object} 事件对象<br>_info.node_: {Object} 目标节点<br>_info.expandedKeys_: {Array} 当前展开的节点key的数组                                                                                                                                                                                               | Function                | func.noop  |
| onDragOver          | 拖拽节点在目标节点上移动的时候触发的回调函数<br><br>**签名**:<br>Function(info: Object) => void<br>**参数**:<br>_info_: {Object} 拖拽信息<br>_info.event_: {Object} 事件对象<br>_info.node_: {Object} 目标节点                                                                                                                                                                                                                                         | Function                | func.noop  |
| onDragLeave         | 拖拽节点离开目标节点时触发的回调函数<br><br>**签名**:<br>Function(info: Object) => void<br>**参数**:<br>_info_: {Object} 拖拽信息<br>_info.event_: {Object} 事件对象<br>_info.node_: {Object} 目标节点                                                                                                                                                                                                                                             | Function                | func.noop  |
| onDragEnd           | 拖拽节点拖拽结束时触发的回调函数<br><br>**签名**:<br>Function(info: Object) => void<br>**参数**:<br>_info_: {Object} 拖拽信息<br>_info.event_: {Object} 事件对象<br>_info.node_: {Object} 目标节点                                                                                                                                                                                                                                               | Function                | func.noop  |
| onDrop              | 拖拽节点放入目标节点内或前后触发的回调函数<br><br>**签名**:<br>Function(info: Object) => void<br>**参数**:<br>_info_: {Object} 拖拽信息<br>_info.event_: {Object} 事件对象<br>_info.node_: {Object} 目标节点<br>_info.dragNode_: {Object} 拖拽的节点<br>_info.dragNodesKeys_: {Array} 拖拽的节点和其子节点 key 的数组<br>_info.dropPosition_: {Number} 放置位置，-1代表当前节点前，0代表当前节点里，1代表当前节点后                                                                                 | Function                | func.noop  |
| canDrop             | 节点是否可被作为拖拽的目标节点<br><br>**签名**:<br>Function(info: Object) => Boolean<br>**参数**:<br>_info_: {Object} 拖拽信息<br>_info.node_: {Object} 目标节点<br>_info.dragNode_: {Object} 拖拽的节点<br>_info.dragNodesKeys_: {Array} 拖拽的节点和其子节点 key 的数组<br>_info.dropPosition_: {Number} 放置位置，-1代表当前节点前，0代表当前节点里，1代表当前节点后<br>**返回值**:<br>{Boolean} 是否可以被当作目标节点<br>                                                                          | Function                | () => true |
| loadData            | 异步加载数据的函数<br><br>**签名**:<br>Function(node: Object) => void<br>**参数**:<br>_node_: {Object} 被点击展开的节点                                                                                                                                                                                                                                                                                                               | Function                | -          |
| filterTreeNode      | 按需筛选高亮节点<br><br>**签名**:<br>Function(node: Object) => Boolean<br>**参数**:<br>_node_: {Object} 待筛选的节点<br>**返回值**:<br>{Boolean} 是否被筛选中<br>                                                                                                                                                                                                                                                                           | Function                | -          |
| onRightClick        | 右键点击节点时触发的回调函数<br><br>**签名**:<br>Function(info: Object) => void<br>**参数**:<br>_info_: {Object} 信息对象<br>_info.event_: {Object} 事件对象<br>_info.node_: {Object} 点击的节点                                                                                                                                                                                                                                                | Function                | func.noop  |
| isLabelBlock        | 设置节点是否占满剩余空间，一般用于统一在各节点右侧添加元素(借助 flex 实现，暂时只支持 ie10+)                                                                                                                                                                                                                                                                                                                                                            | Boolean                 | false      |
| isNodeBlock         | 设置节点是否占满一行                                                                                                                                                                                                                                                                                                                                                                                                       | Boolean/Object          | false      |
| animation           | 是否开启展开收起动画                                                                                                                                                                                                                                                                                                                                                                                                       | Boolean                 | true       |
| focusedKey          | 当前获得焦点的子菜单或菜单项 key 值                                                                                                                                                                                                                                                                                                                                                                                             | String                  | -          |
| renderChildNodes    | 渲染子节点<br><br>**签名**:<br>Function(nodes: Array) => ReactNode<br>**参数**:<br>_nodes_: {Array} 所有的子节点<br>**返回值**:<br>{ReactNode} 返回节点<br>                                                                                                                                                                                                                                                                            | Function                | -          |
| useVirtual          | 是否开启虚拟滚动                                                                                                                                                                                                                                                                                                                                                                                                         | Boolean                 | false      |

### Tree.Node

| 参数               | 说明                                                         | 类型               | 默认值   |
| ---------------- | ---------------------------------------------------------- | ---------------- | ----- |
| children         | 树节点                                                        | ReactNode        | -     |
| label            | 节点文本内容                                                     | ReactNode        | '---' |
| selectable       | 单独设置是否支持选中，覆盖 Tree 的 selectable                            | Boolean          | -     |
| checkable        | 单独设置是否出现复选框，覆盖 Tree 的 checkable                            | Boolean          | -     |
| editable         | 单独设置是否支持编辑，覆盖 Tree 的 editable                              | Boolean          | -     |
| draggable        | 单独设置是否支持拖拽，覆盖 Tree 的 draggable                             | Boolean          | -     |
| disabled         | 是否禁止节点响应                                                   | Boolean          | false |
| checkboxDisabled | 是否禁止勾选节点复选框                                                | Boolean          | false |
| isLeaf           | 是否是叶子节点，设置loadData时生效                                      | Boolean          | -     |
| icon             | 自定义图标，可以使用 Icon 的 type，也可以使用组件 `<Icon type="icon type" />` | String/ReactNode | -     |

<!-- api-extra-start -->

可以为 Tree.Node 设置 `key` 值：`<TreeNode key="102894" label="女装" />`，一般为数据的 id 值，但必需保证其全局唯一性，`key` 的默认值为 Tree 内部计算出的位置字符串。

<!-- api-extra-end -->
