{"meta":"<h2 id=\"guide\">Guide<a href=\"#guide\" class=\"anchor\">#</a></h2><h3 id=\"when-to-use\">When To Use<a href=\"#when-to-use\" class=\"anchor\">#</a></h3><ul>\n<li>Applies to the interactive way of selecting from a set of related data sets.</li>\n<li>Cascading is an effective method of saving screen space due to the hidden subset directory.</li>\n<li>The number of levels depends on the business needs, and it is not recommended to exceed 5 levels.</li>\n<li>Cascading is used for form scenes. It can be used independently on the page or in combination with other elements, such as cascading options.</li>\n</ul>\n<h2 id=\"api\">API<a href=\"#api\" class=\"anchor\">#</a></h2>","api":"<h3 id=\"cascader\">Cascader<a href=\"#cascader\" class=\"anchor\">#</a></h3><table>\n<thead>\n<tr>\n<th>Param</th>\n<th>Description</th>\n<th>Type</th>\n<th>Default Value</th>\n</tr>\n</thead>\n<tbody>\n<tr>\n<td>dataSource</td>\n<td>data source, structure can refer to the following document</td>\n<td>Array&lt;Object&gt;</td>\n<td>[]</td>\n</tr>\n<tr>\n<td>defaultValue</td>\n<td>(under uncontrol) default value</td>\n<td>String/Array&lt;String&gt;</td>\n<td>null</td>\n</tr>\n<tr>\n<td>value</td>\n<td>(under control) current value</td>\n<td>String/Array&lt;String&gt;</td>\n<td>-</td>\n</tr>\n<tr>\n<td>onChange</td>\n<td>callback triggered when value changes<br><br><strong>signatures</strong>:<br>Function(value: String/Array, data: Object/Array, extra: Object) =&gt; void<br><strong>params</strong>:<br><em>value</em>: {String/Array} selected value, a single value is returned when single select, and an array is returned when multiple select<br><em>data</em>: {Object/Array} selected data, including value, label, returns a single value when single select, returns an array when multiple select, parent and child nodes are selected at the same time, only the parent node is returned<br><em>extra</em>: {Object} extra param<br><em>extra.selectedPath</em>: {Array} path of the selected data when single selecte<br><em>extra.checked</em>: {Boolean} whether is checked when multiple select<br><em>extra.currentData</em>: {Object} current operation data when multiple select<br><em>extra.checkedData</em>: {Array} all checked data when multiple select<br><em>extra.indeterminateData</em>: {Array} indeterminate data when multile select</td>\n<td>Function</td>\n<td>-</td>\n</tr>\n<tr>\n<td>defaultExpandedValue</td>\n<td>(under uncontrol) default expanded value, if not set, the component will be automatically set according to defaultValue/value</td>\n<td>Array&lt;String&gt;</td>\n<td>-</td>\n</tr>\n<tr>\n<td>expandedValue</td>\n<td>(under control) current expanded value</td>\n<td>Array&lt;String&gt;</td>\n<td>-</td>\n</tr>\n<tr>\n<td>expandTriggerType</td>\n<td>expand trigger type<br><br><strong>options</strong>:<br>&apos;click&apos;, &apos;hover&apos;</td>\n<td>Enum</td>\n<td>&apos;click&apos;</td>\n</tr>\n<tr>\n<td>onExpand</td>\n<td>callback triggered when expand or collapse<br><br><strong>signatures</strong>:<br>Function(expandedValue: Array) =&gt; void<br><strong>params</strong>:<br><em>expandedValue</em>: {Array} an array of list expanded values</td>\n<td>Function</td>\n<td>-</td>\n</tr>\n<tr>\n<td>multiple</td>\n<td>whether is multiple select</td>\n<td>Boolean</td>\n<td>false</td>\n</tr>\n<tr>\n<td>canOnlySelectLeaf</td>\n<td>whether only leaf nodes can be selected when single select</td>\n<td>Boolean</td>\n<td>false</td>\n</tr>\n<tr>\n<td>canOnlyCheckLeaf</td>\n<td>whether only leaf nodes can be checked when multiple select</td>\n<td>Boolean</td>\n<td>false</td>\n</tr>\n<tr>\n<td>checkStrictly</td>\n<td>whether selection of parent and child nodes are related</td>\n<td>Boolean</td>\n<td>false</td>\n</tr>\n<tr>\n<td>listStyle</td>\n<td>style of list</td>\n<td>Object</td>\n<td>-</td>\n</tr>\n<tr>\n<td>listClassName</td>\n<td>class name of list</td>\n<td>String</td>\n<td>-</td>\n</tr>\n<tr>\n<td>itemRender</td>\n<td>render function of item<br><br><strong>signatures</strong>:<br>Function(data: Object) =&gt; ReactNode<br><strong>params</strong>:<br><em>data</em>: {Object} data<br><strong>returns</strong>:<br>{ReactNode} content of item<br></td>\n<td>Function</td>\n<td>item =&gt; item.label</td>\n</tr>\n<tr>\n<td>loadData</td>\n<td>asynchronous data loading function<br><br><strong>signatures</strong>:<br>Function(data: Object) =&gt; void<br><strong>params</strong>:<br><em>data</em>: {Object} clicked item</td>\n<td>Function</td>\n<td>-</td>\n</tr>\n</tbody>\n</table>\n<!-- api-extra-start -->\n<h3 id=\"data-structure-of-datasource\">Data structure of dataSource<a href=\"#data-structure-of-datasource\" class=\"anchor\">#</a></h3><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">const</span> dataSource <span class=\"token operator\">=</span> <span class=\"token punctuation\">[</span><span class=\"token punctuation\">{</span>\n    value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;2974&apos;</span><span class=\"token punctuation\">,</span>\n    label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;A&apos;</span><span class=\"token punctuation\">,</span>\n    children<span class=\"token operator\">:</span> <span class=\"token punctuation\">[</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;2975&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;B&apos;</span><span class=\"token punctuation\">,</span> disabled<span class=\"token operator\">:</span> <span class=\"token boolean\">true</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;2976&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;C&apos;</span><span class=\"token punctuation\">,</span> checkboxDisabled<span class=\"token operator\">:</span> <span class=\"token boolean\">true</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;2977&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;D&apos;</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;2978&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;E&apos;</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;2979&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;F&apos;</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;4208&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;G&apos;</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;4209&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;H&apos;</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;4210&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;I&apos;</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;4211&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;J&apos;</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;4212&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;K&apos;</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;4213&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;L&apos;</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;4214&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;M&apos;</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;4215&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;N&apos;</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;4388&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;O&apos;</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span> value<span class=\"token operator\">:</span> <span class=\"token string\">&apos;610127&apos;</span><span class=\"token punctuation\">,</span> label<span class=\"token operator\">:</span> <span class=\"token string\">&apos;P&apos;</span> <span class=\"token punctuation\">}</span>\n    <span class=\"token punctuation\">]</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span></code></pre></div><p>The custom attribute of item in the array is also transparently passed to the data parameter of the onChange function.</p>\n<!-- api-extra-end -->\n<h2 id=\"aria-and-keyboard\">ARIA and KeyBoard<a href=\"#aria-and-keyboard\" class=\"anchor\">#</a></h2><table>\n<thead>\n<tr>\n<th style=\"text-align:left\">&#x6309;&#x952E;</th>\n<th style=\"text-align:left\">&#x8BF4;&#x660E;</th>\n</tr>\n</thead>\n<tbody>\n<tr>\n<td style=\"text-align:left\">Left Arrow</td>\n<td style=\"text-align:left\">Get the previous item focus of the current item of same level</td>\n</tr>\n<tr>\n<td style=\"text-align:left\">Right Arrow</td>\n<td style=\"text-align:left\">Get the next item focus of the current item of same level</td>\n</tr>\n<tr>\n<td style=\"text-align:left\">Tab</td>\n<td style=\"text-align:left\">Enter the child element of the current item and get the first child element as the focus</td>\n</tr>\n<tr>\n<td style=\"text-align:left\">Esc</td>\n<td style=\"text-align:left\">Returns the parent of the current item and gets the focus</td>\n</tr>\n<tr>\n<td style=\"text-align:left\">SPACE</td>\n<td style=\"text-align:left\">Select current item</td>\n</tr>\n</tbody>\n</table>\n"}