{"title":"Internationalization","meta":{"title":"Internationalization","description":"\n<p>Demo how to use ConfigProvider to implement components with international capabilities.</p>\n","order":"0"},"codes":{"jsx":"import { ConfigProvider, Button, Select } from '@alifd/next';\nimport PropTypes from 'prop-types';\n\nconst { config, getContextProps } = ConfigProvider;\nconst { Option } = Select;\n\nconst locales = {\n    'zh-cn': {\n        ClickMe: {\n            clickMe: '点我！'\n        },\n        Toast: {\n            close: '关闭'\n        }\n    },\n    'en-us': {\n        ClickMe: {\n            clickMe: 'click me!'\n        },\n        Toast: {\n            close: 'close'\n        }\n    }\n};\n\nclass ClickMe extends React.Component {\n    static propTypes = {\n        locale: PropTypes.object,\n        onClick: PropTypes.func\n    };\n\n    static defaultProps = {\n        locale: locales['zh-cn'].ClickMe,\n        onClick: () => {}\n    };\n\n    render() {\n        const { locale, onClick } = this.props;\n        return (\n            <Button onClick={onClick}>{locale.clickMe}</Button>\n        );\n    }\n}\n\nclass Toast extends React.Component {\n    static propTypes = {\n        locale: PropTypes.object,\n        afterClose: PropTypes.func\n    };\n\n    static defaultProps = {\n        locale: locales['zh-cn'].Toast,\n        afterClose: () => {}\n    };\n\n    constructor(props) {\n        super(props);\n\n        this.state = {\n            visible: false\n        };\n\n        this.handleClose = this.handleClose.bind(this);\n    }\n\n    handleClose() {\n        this.setState({\n            visible: false\n        });\n        this.props.afterClose();\n    }\n\n    render() {\n        return (\n            <div className=\"toast\">\n                <Button type=\"primary\" onClick={this.handleClose}>\n                    {this.props.locale.close}\n                </Button>\n            </div>\n        );\n    }\n}\nToast.create = (props = {}) => {\n    const mountNode = document.createElement('div');\n    document.body.appendChild(mountNode);\n\n    const closeChain = () => {\n        ReactDOM.unmountComponentAtNode(mountNode);\n        document.body.removeChild(mountNode);\n    };\n\n    const newLocale = getContextProps(props, 'Toast').locale;\n\n    ReactDOM.render(<Toast afterClose={closeChain} locale={newLocale} />, mountNode);\n};\n\nconst NewClickMe = config(ClickMe);\nconst NewToast = config(Toast);\n\nclass Demo extends React.Component {\n    constructor(props) {\n        super(props);\n\n        this.state = {\n            language: 'zh-cn'\n        };\n\n        this.handleClick = this.handleClick.bind(this);\n        this.handleChangeLanguage = this.handleChangeLanguage.bind(this);\n    }\n\n    handleClick() {\n        NewToast.create();\n    }\n\n    handleChangeLanguage(language) {\n        this.setState({\n            language\n        });\n    }\n\n    render() {\n        const { language } = this.state;\n\n        return (\n            <ConfigProvider locale={locales[language]}>\n                <div>\n                    <div className=\"select-language\">\n                        <Select value={language} onChange={this.handleChangeLanguage}>\n                            <Option value=\"zh-cn\">zh-cn</Option>\n                            <Option value=\"en-us\">en-us</Option>\n                        </Select>\n                    </div>\n                    <NewClickMe onClick={this.handleClick} />\n                </div>\n            </ConfigProvider>\n        );\n    }\n}\n\nReactDOM.render(<Demo />, mountNode);\n","css":".toast {\n    position: fixed;\n    top: 0;\n    right: 0;\n    bottom: 0;\n    left: 0;\n    margin: auto;\n    width: 200px;\n    height: 100px;\n    line-height: 100px;\n    text-align: center;\n    background: white;\n    box-shadow: 3px 3px 5px 0 rgba(0, 0, 0, .32);\n}\n\n.toast .next-btn {\n    margin: auto;\n}\n\n.select-language {\n    margin-bottom: 20px;\n}\n"},"body":"\n````jsx\nimport { ConfigProvider, Button, Select } from '@alifd/next';\nimport PropTypes from 'prop-types';\n\nconst { config, getContextProps } = ConfigProvider;\nconst { Option } = Select;\n\nconst locales = {\n    'zh-cn': {\n        ClickMe: {\n            clickMe: '点我！'\n        },\n        Toast: {\n            close: '关闭'\n        }\n    },\n    'en-us': {\n        ClickMe: {\n            clickMe: 'click me!'\n        },\n        Toast: {\n            close: 'close'\n        }\n    }\n};\n\nclass ClickMe extends React.Component {\n    static propTypes = {\n        locale: PropTypes.object,\n        onClick: PropTypes.func\n    };\n\n    static defaultProps = {\n        locale: locales['zh-cn'].ClickMe,\n        onClick: () => {}\n    };\n\n    render() {\n        const { locale, onClick } = this.props;\n        return (\n            <Button onClick={onClick}>{locale.clickMe}</Button>\n        );\n    }\n}\n\nclass Toast extends React.Component {\n    static propTypes = {\n        locale: PropTypes.object,\n        afterClose: PropTypes.func\n    };\n\n    static defaultProps = {\n        locale: locales['zh-cn'].Toast,\n        afterClose: () => {}\n    };\n\n    constructor(props) {\n        super(props);\n\n        this.state = {\n            visible: false\n        };\n\n        this.handleClose = this.handleClose.bind(this);\n    }\n\n    handleClose() {\n        this.setState({\n            visible: false\n        });\n        this.props.afterClose();\n    }\n\n    render() {\n        return (\n            <div className=\"toast\">\n                <Button type=\"primary\" onClick={this.handleClose}>\n                    {this.props.locale.close}\n                </Button>\n            </div>\n        );\n    }\n}\nToast.create = (props = {}) => {\n    const mountNode = document.createElement('div');\n    document.body.appendChild(mountNode);\n\n    const closeChain = () => {\n        ReactDOM.unmountComponentAtNode(mountNode);\n        document.body.removeChild(mountNode);\n    };\n\n    const newLocale = getContextProps(props, 'Toast').locale;\n\n    ReactDOM.render(<Toast afterClose={closeChain} locale={newLocale} />, mountNode);\n};\n\nconst NewClickMe = config(ClickMe);\nconst NewToast = config(Toast);\n\nclass Demo extends React.Component {\n    constructor(props) {\n        super(props);\n\n        this.state = {\n            language: 'zh-cn'\n        };\n\n        this.handleClick = this.handleClick.bind(this);\n        this.handleChangeLanguage = this.handleChangeLanguage.bind(this);\n    }\n\n    handleClick() {\n        NewToast.create();\n    }\n\n    handleChangeLanguage(language) {\n        this.setState({\n            language\n        });\n    }\n\n    render() {\n        const { language } = this.state;\n\n        return (\n            <ConfigProvider locale={locales[language]}>\n                <div>\n                    <div className=\"select-language\">\n                        <Select value={language} onChange={this.handleChangeLanguage}>\n                            <Option value=\"zh-cn\">zh-cn</Option>\n                            <Option value=\"en-us\">en-us</Option>\n                        </Select>\n                    </div>\n                    <NewClickMe onClick={this.handleClick} />\n                </div>\n            </ConfigProvider>\n        );\n    }\n}\n\nReactDOM.render(<Demo />, mountNode);\n````\n\n```` css\n.toast {\n    position: fixed;\n    top: 0;\n    right: 0;\n    bottom: 0;\n    left: 0;\n    margin: auto;\n    width: 200px;\n    height: 100px;\n    line-height: 100px;\n    text-align: center;\n    background: white;\n    box-shadow: 3px 3px 5px 0 rgba(0, 0, 0, .32);\n}\n\n.toast .next-btn {\n    margin: auto;\n}\n\n.select-language {\n    margin-bottom: 20px;\n}\n````","html":"<script>(function(){'use strict';\n\nvar _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();\n\nvar _next = require('@alifd/next');\n\nvar _propTypes = require('prop-types');\n\nvar _propTypes2 = _interopRequireDefault(_propTypes);\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return call && (typeof call === \"object\" || typeof call === \"function\") ? call : self; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function, not \" + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }\n\nvar config = _next.ConfigProvider.config,\n    getContextProps = _next.ConfigProvider.getContextProps;\nvar Option = _next.Select.Option;\n\n\nvar locales = {\n    'zh-cn': {\n        ClickMe: {\n            clickMe: '点我！'\n        },\n        Toast: {\n            close: '关闭'\n        }\n    },\n    'en-us': {\n        ClickMe: {\n            clickMe: 'click me!'\n        },\n        Toast: {\n            close: 'close'\n        }\n    }\n};\n\nvar ClickMe = function (_React$Component) {\n    _inherits(ClickMe, _React$Component);\n\n    function ClickMe() {\n        _classCallCheck(this, ClickMe);\n\n        return _possibleConstructorReturn(this, (ClickMe.__proto__ || Object.getPrototypeOf(ClickMe)).apply(this, arguments));\n    }\n\n    _createClass(ClickMe, [{\n        key: 'render',\n        value: function render() {\n            var _props = this.props,\n                locale = _props.locale,\n                onClick = _props.onClick;\n\n            return React.createElement(\n                _next.Button,\n                { onClick: onClick },\n                locale.clickMe\n            );\n        }\n    }]);\n\n    return ClickMe;\n}(React.Component);\n\nClickMe.propTypes = {\n    locale: _propTypes2.default.object,\n    onClick: _propTypes2.default.func\n};\nClickMe.defaultProps = {\n    locale: locales['zh-cn'].ClickMe,\n    onClick: function onClick() {}\n};\n\nvar Toast = function (_React$Component2) {\n    _inherits(Toast, _React$Component2);\n\n    function Toast(props) {\n        _classCallCheck(this, Toast);\n\n        var _this2 = _possibleConstructorReturn(this, (Toast.__proto__ || Object.getPrototypeOf(Toast)).call(this, props));\n\n        _this2.state = {\n            visible: false\n        };\n\n        _this2.handleClose = _this2.handleClose.bind(_this2);\n        return _this2;\n    }\n\n    _createClass(Toast, [{\n        key: 'handleClose',\n        value: function handleClose() {\n            this.setState({\n                visible: false\n            });\n            this.props.afterClose();\n        }\n    }, {\n        key: 'render',\n        value: function render() {\n            return React.createElement(\n                'div',\n                { className: 'toast' },\n                React.createElement(\n                    _next.Button,\n                    { type: 'primary', onClick: this.handleClose },\n                    this.props.locale.close\n                )\n            );\n        }\n    }]);\n\n    return Toast;\n}(React.Component);\n\nToast.propTypes = {\n    locale: _propTypes2.default.object,\n    afterClose: _propTypes2.default.func\n};\nToast.defaultProps = {\n    locale: locales['zh-cn'].Toast,\n    afterClose: function afterClose() {}\n};\n\nToast.create = function () {\n    var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};\n\n    var mountNode = document.createElement('div');\n    document.body.appendChild(mountNode);\n\n    var closeChain = function closeChain() {\n        ReactDOM.unmountComponentAtNode(mountNode);\n        document.body.removeChild(mountNode);\n    };\n\n    var newLocale = getContextProps(props, 'Toast').locale;\n\n    ReactDOM.render(React.createElement(Toast, { afterClose: closeChain, locale: newLocale }), mountNode);\n};\n\nvar NewClickMe = config(ClickMe);\nvar NewToast = config(Toast);\n\nvar Demo = function (_React$Component3) {\n    _inherits(Demo, _React$Component3);\n\n    function Demo(props) {\n        _classCallCheck(this, Demo);\n\n        var _this3 = _possibleConstructorReturn(this, (Demo.__proto__ || Object.getPrototypeOf(Demo)).call(this, props));\n\n        _this3.state = {\n            language: 'zh-cn'\n        };\n\n        _this3.handleClick = _this3.handleClick.bind(_this3);\n        _this3.handleChangeLanguage = _this3.handleChangeLanguage.bind(_this3);\n        return _this3;\n    }\n\n    _createClass(Demo, [{\n        key: 'handleClick',\n        value: function handleClick() {\n            NewToast.create();\n        }\n    }, {\n        key: 'handleChangeLanguage',\n        value: function handleChangeLanguage(language) {\n            this.setState({\n                language: language\n            });\n        }\n    }, {\n        key: 'render',\n        value: function render() {\n            var language = this.state.language;\n\n\n            return React.createElement(\n                _next.ConfigProvider,\n                { locale: locales[language] },\n                React.createElement(\n                    'div',\n                    null,\n                    React.createElement(\n                        'div',\n                        { className: 'select-language' },\n                        React.createElement(\n                            _next.Select,\n                            { value: language, onChange: this.handleChangeLanguage },\n                            React.createElement(\n                                Option,\n                                { value: 'zh-cn' },\n                                'zh-cn'\n                            ),\n                            React.createElement(\n                                Option,\n                                { value: 'en-us' },\n                                'en-us'\n                            )\n                        )\n                    ),\n                    React.createElement(NewClickMe, { onClick: this.handleClick })\n                )\n            );\n        }\n    }]);\n\n    return Demo;\n}(React.Component);\n\nReactDOM.render(React.createElement(Demo, null), mountNode);})()</script><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> ConfigProvider<span class=\"token punctuation\">,</span> Button<span class=\"token punctuation\">,</span> Select <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next'</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">import</span> PropTypes <span class=\"token keyword\">from</span> <span class=\"token string\">'prop-types'</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> config<span class=\"token punctuation\">,</span> getContextProps <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> ConfigProvider<span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> Option <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> Select<span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> locales <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token string\">'zh-cn'</span><span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n        ClickMe<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n            clickMe<span class=\"token operator\">:</span> <span class=\"token string\">'点我！'</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        Toast<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n            close<span class=\"token operator\">:</span> <span class=\"token string\">'关闭'</span>\n        <span class=\"token punctuation\">}</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    <span class=\"token string\">'en-us'</span><span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n        ClickMe<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n            clickMe<span class=\"token operator\">:</span> <span class=\"token string\">'click me!'</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        Toast<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n            close<span class=\"token operator\">:</span> <span class=\"token string\">'close'</span>\n        <span class=\"token punctuation\">}</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">ClickMe</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">static</span> propTypes <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n        locale<span class=\"token operator\">:</span> PropTypes<span class=\"token punctuation\">.</span>object<span class=\"token punctuation\">,</span>\n        onClick<span class=\"token operator\">:</span> PropTypes<span class=\"token punctuation\">.</span>func\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token keyword\">static</span> defaultProps <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n        locale<span class=\"token operator\">:</span> locales<span class=\"token punctuation\">[</span><span class=\"token string\">'zh-cn'</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">.</span>ClickMe<span class=\"token punctuation\">,</span>\n        <span class=\"token function-variable function\">onClick</span><span class=\"token operator\">:</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span><span class=\"token punctuation\">}</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> locale<span class=\"token punctuation\">,</span> onClick <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span>\n            <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>onClick<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>locale<span class=\"token punctuation\">.</span>clickMe<span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span>\n        <span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">Toast</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">static</span> propTypes <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n        locale<span class=\"token operator\">:</span> PropTypes<span class=\"token punctuation\">.</span>object<span class=\"token punctuation\">,</span>\n        afterClose<span class=\"token operator\">:</span> PropTypes<span class=\"token punctuation\">.</span>func\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token keyword\">static</span> defaultProps <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n        locale<span class=\"token operator\">:</span> locales<span class=\"token punctuation\">[</span><span class=\"token string\">'zh-cn'</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">.</span>Toast<span class=\"token punctuation\">,</span>\n        <span class=\"token function-variable function\">afterClose</span><span class=\"token operator\">:</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span><span class=\"token punctuation\">}</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token function\">constructor</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">props</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">super</span><span class=\"token punctuation\">(</span>props<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n            visible<span class=\"token operator\">:</span> <span class=\"token boolean\">false</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>handleClose <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">handleClose</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">handleClose</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setState</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            visible<span class=\"token operator\">:</span> <span class=\"token boolean\">false</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">.</span><span class=\"token function\">afterClose</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span>\n            <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>toast<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">type</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>primary<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>handleClose<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">.</span>locale<span class=\"token punctuation\">.</span>close<span class=\"token punctuation\">}</span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span>\n        <span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\nToast<span class=\"token punctuation\">.</span><span class=\"token function-variable function\">create</span> <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token parameter\">props <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">const</span> mountNode <span class=\"token operator\">=</span> document<span class=\"token punctuation\">.</span><span class=\"token function\">createElement</span><span class=\"token punctuation\">(</span><span class=\"token string\">'div'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    document<span class=\"token punctuation\">.</span>body<span class=\"token punctuation\">.</span><span class=\"token function\">appendChild</span><span class=\"token punctuation\">(</span>mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token keyword\">const</span> <span class=\"token function-variable function\">closeChain</span> <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n        ReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">unmountComponentAtNode</span><span class=\"token punctuation\">(</span>mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n        document<span class=\"token punctuation\">.</span>body<span class=\"token punctuation\">.</span><span class=\"token function\">removeChild</span><span class=\"token punctuation\">(</span>mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token keyword\">const</span> newLocale <span class=\"token operator\">=</span> <span class=\"token function\">getContextProps</span><span class=\"token punctuation\">(</span>props<span class=\"token punctuation\">,</span> <span class=\"token string\">'Toast'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">.</span>locale<span class=\"token punctuation\">;</span>\n\n    ReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Toast</span></span> <span class=\"token attr-name\">afterClose</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>closeChain<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">locale</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>newLocale<span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token punctuation\">,</span> mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> NewClickMe <span class=\"token operator\">=</span> <span class=\"token function\">config</span><span class=\"token punctuation\">(</span>ClickMe<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">const</span> NewToast <span class=\"token operator\">=</span> <span class=\"token function\">config</span><span class=\"token punctuation\">(</span>Toast<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">Demo</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token function\">constructor</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">props</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">super</span><span class=\"token punctuation\">(</span>props<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n            language<span class=\"token operator\">:</span> <span class=\"token string\">'zh-cn'</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>handleClick <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">handleClick</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>handleChangeLanguage <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">handleChangeLanguage</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">handleClick</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        NewToast<span class=\"token punctuation\">.</span><span class=\"token function\">create</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">handleChangeLanguage</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">language</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setState</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            language\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> language <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span>\n            <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">ConfigProvider</span></span> <span class=\"token attr-name\">locale</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>locales<span class=\"token punctuation\">[</span>language<span class=\"token punctuation\">]</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>select-language<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select</span></span> <span class=\"token attr-name\">value</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>language<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">onChange</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>handleChangeLanguage<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Option</span></span> <span class=\"token attr-name\">value</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>zh-cn<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">zh-cn</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Option</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Option</span></span> <span class=\"token attr-name\">value</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>en-us<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">en-us</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Option</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Select</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">NewClickMe</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>handleClick<span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">ConfigProvider</span></span><span class=\"token punctuation\">></span></span>\n        <span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\n\nReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Demo</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token punctuation\">,</span> mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><style type=\"text/css\">.toast {\n    position: fixed;\n    top: 0;\n    right: 0;\n    bottom: 0;\n    left: 0;\n    margin: auto;\n    width: 200px;\n    height: 100px;\n    line-height: 100px;\n    text-align: center;\n    background: white;\n    box-shadow: 3px 3px 5px 0 rgba(0, 0, 0, .32);\n}\n\n.toast .next-btn {\n    margin: auto;\n}\n\n.select-language {\n    margin-bottom: 20px;\n}</style><div class=\"highlight\"><pre class=\"language-css\"><code class=\"language-css\"><span class=\"token selector\">.toast</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">position</span><span class=\"token punctuation\">:</span> fixed<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">top</span><span class=\"token punctuation\">:</span> 0<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">right</span><span class=\"token punctuation\">:</span> 0<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">bottom</span><span class=\"token punctuation\">:</span> 0<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">left</span><span class=\"token punctuation\">:</span> 0<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">margin</span><span class=\"token punctuation\">:</span> auto<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">width</span><span class=\"token punctuation\">:</span> 200px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">height</span><span class=\"token punctuation\">:</span> 100px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">line-height</span><span class=\"token punctuation\">:</span> 100px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">text-align</span><span class=\"token punctuation\">:</span> center<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">background</span><span class=\"token punctuation\">:</span> white<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">box-shadow</span><span class=\"token punctuation\">:</span> 3px 3px 5px 0 <span class=\"token function\">rgba</span><span class=\"token punctuation\">(</span>0<span class=\"token punctuation\">,</span> 0<span class=\"token punctuation\">,</span> 0<span class=\"token punctuation\">,</span> .32<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token selector\">.toast .next-btn</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">margin</span><span class=\"token punctuation\">:</span> auto<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token selector\">.select-language</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">margin-bottom</span><span class=\"token punctuation\">:</span> 20px<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span></code></pre></div>"}