{"meta":"<h2 id=\"guide\">Guide<a href=\"#guide\" class=\"anchor\">#</a></h2><h3 id=\"when-to-use\">When To Use<a href=\"#when-to-use\" class=\"anchor\">#</a></h3><ul>\n<li>Modify the component class name prefix, the default prefix of the Next component class name is &apos;next-&apos;, such as &apos;next-btn&apos;, you may want to change this default prefix in the following two cases:<ul>\n<li>Custom component brands such as &apos;my-btn&apos;, &apos;my-select&apos;</li>\n<li>Two themes in a page at the same time, preventing the same class name from overwriting each other</li>\n</ul>\n</li>\n<li>Support multiple languages</li>\n<li>Enable Pure Render mode to improve performance, and note that it may have side effects</li>\n</ul>\n<h3 id=\"basic-usage\">Basic Usage<a href=\"#basic-usage\" class=\"anchor\">#</a></h3><h4 id=\"specify-language\">Specify language<a href=\"#specify-language\" class=\"anchor\">#</a></h4><p>Now support four languages: Simplified Chinese, Traditional Chinese, English and Japanese.</p>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> ConfigProvider<span class=\"token punctuation\">,</span> DatePicker <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">&apos;@alifd/next&apos;</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">import</span> enUS <span class=\"token keyword\">from</span> <span class=\"token string\">&apos;@alifd/next/lib/locale/en-us&apos;</span><span class=\"token punctuation\">;</span>\n<span class=\"token comment\">// import zhCN from &apos;@alifd/next/lib/locale/zh-cn&apos;;</span>\n<span class=\"token comment\">// import zhHK from &apos;@alifd/next/lib/locale/zh-hk&apos;;</span>\n<span class=\"token comment\">// import zhTW from &apos;@alifd/next/lib/locale/zh-tw&apos;;</span>\n<span class=\"token comment\">// import jaJP from &apos;@alifd/next/lib/locale/ja-jp&apos;;</span>\n\n<span class=\"token comment\">// If the application directly imports the next-with-locales.js file from cdn</span>\n<span class=\"token comment\">// it need to import locale file in the following way</span>\n<span class=\"token comment\">// const { ConfigProvider, DatePicker, locales } = window.Next;</span>\n<span class=\"token comment\">// const enUS = locales[&apos;en-us&apos;];</span>\n\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">App</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span>\n            <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">ConfigProvider</span></span> <span class=\"token attr-name\">locale</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>enUS<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">&gt;</span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">DatePicker</span></span> <span class=\"token punctuation\">/&gt;</span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">ConfigProvider</span></span><span class=\"token punctuation\">&gt;</span></span>\n        <span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span></code></pre></div><p>The passed locale object has the following format:</p>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token punctuation\">{</span>\n    DatePicker<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n        datePlaceholder<span class=\"token operator\">:</span> <span class=\"token string\">&apos;Select date&apos;</span><span class=\"token punctuation\">,</span>\n        monthPlaceholder<span class=\"token operator\">:</span> <span class=\"token string\">&apos;Select month&apos;</span><span class=\"token punctuation\">,</span>\n        yearPlaceholder<span class=\"token operator\">:</span> <span class=\"token string\">&apos;Select year&apos;</span><span class=\"token punctuation\">,</span>\n        rangeStartPlaceholder<span class=\"token operator\">:</span> <span class=\"token string\">&apos;Start date&apos;</span><span class=\"token punctuation\">,</span>\n        rangeEndPlaceholder<span class=\"token operator\">:</span> <span class=\"token string\">&apos;End date&apos;</span><span class=\"token punctuation\">,</span>\n        ok<span class=\"token operator\">:</span> <span class=\"token string\">&apos;OK&apos;</span><span class=\"token punctuation\">,</span>\n        clear<span class=\"token operator\">:</span> <span class=\"token string\">&apos;Clear&apos;</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    Dialog<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token comment\">// ...</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    <span class=\"token comment\">// ...</span>\n<span class=\"token punctuation\">}</span></code></pre></div><h4 id=\"modify-the-component-class-name-prefix\">Modify the component class name prefix<a href=\"#modify-the-component-class-name-prefix\" class=\"anchor\">#</a></h4><ol>\n<li><p>Wrapper ConfigProvider for your application and set the custom prefix</p>\n<p>entry.jsx</p>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">class</span> <span class=\"token class-name\">App</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span>\n            <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">ConfigProvider</span></span> <span class=\"token attr-name\">prefix</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">&quot;</span>my-<span class=\"token punctuation\">&quot;</span></span><span class=\"token punctuation\">&gt;</span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span><span class=\"token punctuation\">&gt;</span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Input</span></span> <span class=\"token punctuation\">/&gt;</span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">&gt;</span></span><span class=\"token plain-text\">Submit</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">&gt;</span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">&gt;</span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">ConfigProvider</span></span><span class=\"token punctuation\">&gt;</span></span>\n        <span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span></code></pre></div></li>\n<li><p>Set the <code>$css-prefix</code> to the same value before importing the theme scss file in the scss entry file.</p>\n<p>entry.scss</p>\n<div class=\"highlight\"><pre class=\"language-scss\"><code class=\"language-scss\"><span class=\"token property\"><span class=\"token variable\">$css-prefix</span></span><span class=\"token punctuation\">:</span> <span class=\"token string\">&quot;my-&quot;</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">@import</span> <span class=\"token string\">&quot;~@alifd/theme-xxx/index.scss&quot;</span><span class=\"token punctuation\">;</span></code></pre></div></li>\n</ol>\n<h4 id=\"enable-pure-render\">Enable Pure Render<a href=\"#enable-pure-render\" class=\"anchor\">#</a></h4><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> ConfigProvider<span class=\"token punctuation\">,</span> DatePicker <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">&apos;@alifd/next&apos;</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">App</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span>\n            <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">ConfigProvider</span></span> <span class=\"token attr-name\">pure</span><span class=\"token punctuation\">&gt;</span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">DatePicker</span></span> <span class=\"token punctuation\">/&gt;</span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">ConfigProvider</span></span><span class=\"token punctuation\">&gt;</span></span>\n        <span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span></code></pre></div><h4 id=\"how-to-make-the-component-support-configprovider-&#xFF1F;\">How to make the component support ConfigProvider &#xFF1F;<a href=\"#how-to-make-the-component-support-configprovider-&#xFF1F;\" class=\"anchor\">#</a></h4><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> ConfigProvider <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">&apos;@alifd/next&apos;</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">import</span> locale <span class=\"token keyword\">from</span> <span class=\"token string\">&apos;./locale&apos;</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> config <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> ConfigProvider<span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">Component</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">static</span> propTypes <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n        prefix<span class=\"token operator\">:</span> PropTypes<span class=\"token punctuation\">.</span>string<span class=\"token punctuation\">,</span>\n        locale<span class=\"token operator\">:</span> PropTypes<span class=\"token punctuation\">.</span>object<span class=\"token punctuation\">,</span>\n        pure<span class=\"token operator\">:</span> PropTypes<span class=\"token punctuation\">.</span>bool\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token keyword\">static</span> defaultProps <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n        prefix<span class=\"token operator\">:</span> <span class=\"token string\">&apos;next-&apos;</span><span class=\"token punctuation\">,</span>\n        locale<span class=\"token operator\">:</span> locale<span class=\"token punctuation\">,</span>\n        pure<span class=\"token operator\">:</span> <span class=\"token boolean\">false</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> prefix<span class=\"token punctuation\">,</span> locale<span class=\"token punctuation\">,</span> pure <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">;</span>\n        <span class=\"token comment\">// ...</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token keyword\">export</span> <span class=\"token keyword\">default</span> <span class=\"token function\">config</span><span class=\"token punctuation\">(</span>Component<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><h2 id=\"api\">API<a href=\"#api\" class=\"anchor\">#</a></h2>","api":"<h3 id=\"configprovider\">ConfigProvider<a href=\"#configprovider\" class=\"anchor\">#</a></h3><table>\n<thead>\n<tr>\n<th>Param</th>\n<th>Description</th>\n<th>Type</th>\n<th>Default Value</th>\n</tr>\n</thead>\n<tbody>\n<tr>\n<td>errorBoundary</td>\n<td>turn errorBoundary on or not<br>If you pass object, properties&#xFF1A;<br><br>fallbackUI <code>Function(error?: {}, errorInfo?: {}) =&gt; Element</code> <br>afterCatch <code>Function(error?: {}, errorInfo?: {})</code> after being catched, e.g. send data to server for data statistics</td>\n<td>Boolean/Object</td>\n<td>false</td>\n</tr>\n<tr>\n<td>pure</td>\n<td>whether enable the Pure Render mode, it will improve performance, but it will also have side effects</td>\n<td>Boolean</td>\n<td>-</td>\n</tr>\n<tr>\n<td>device</td>\n<td>Responsive of device <br>Options:<br> <code>desktop</code>, <code>tablet</code>, <code>phone</code></td>\n<td>-</td>\n</tr>\n<tr>\n<td>warning</td>\n<td>whether to display the warning prompt for component properties being deprecated in development mode</td>\n<td>Boolean</td>\n<td>true</td>\n</tr>\n<tr>\n<td>children</td>\n<td>component tree</td>\n<td>ReactElement</td>\n<td>-</td>\n</tr>\n<tr>\n<td>popupContainer</td>\n<td>shell container node</td>\n<td>String/Function</td>\n<td>-</td>\n</tr>\n</tbody>\n</table>\n<!-- api-extra-start -->\n<h3 id=\"configprovider-config-component\">ConfigProvider.config(Component)<a href=\"#configprovider-config-component\" class=\"anchor\">#</a></h3><p>Pass the component and generate the HOC that is controlled by the ConfigProvider. If the component does not declare the shouldComponentUpdate method, the following shouldComponentUpdate method is added to support the pure property of the ConfigProvider.</p>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token class-name\">Component</span><span class=\"token punctuation\">.</span>prototype<span class=\"token punctuation\">.</span><span class=\"token function-variable function\">shouldComponentUpdate</span> <span class=\"token operator\">=</span> <span class=\"token keyword\">function</span> <span class=\"token function\">shouldComponentUpdate</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">nextProps<span class=\"token punctuation\">,</span> nextState</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">if</span> <span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">.</span>pure<span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token operator\">!</span><span class=\"token function\">shallowEqual</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">,</span> nextProps<span class=\"token punctuation\">)</span> <span class=\"token operator\">||</span> <span class=\"token operator\">!</span><span class=\"token function\">shallowEqual</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">,</span> nextState<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token keyword\">return</span> <span class=\"token boolean\">true</span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span></code></pre></div><h3 id=\"configprovider-getcontextprops-props-displayname\">ConfigProvider.getContextProps(props, displayName)<a href=\"#configprovider-getcontextprops-props-displayname\" class=\"anchor\">#</a></h3><p>Pass the props and displayName of the component to get the object containing preifx/locale/pure calculated by childContext, it is generally used to generate components that are separated from the component tree through static methods.</p>\n<h3 id=\"configprovider-getcontext\">ConfigProvider.getContext()<a href=\"#configprovider-getcontext\" class=\"anchor\">#</a></h3><p>You can get the context of ConfigProvider via this method. The format of the value returned as follows. For multiple ConfigProvider nested, the results will be merged and the nearer the higher priority&#x3002;</p>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token punctuation\">{</span>\n    prefix<span class=\"token operator\">:</span> nextPrefix<span class=\"token punctuation\">,</span>\n    locale<span class=\"token operator\">:</span> nextLocale<span class=\"token punctuation\">,</span>\n    pure<span class=\"token operator\">:</span> nextPure<span class=\"token punctuation\">,</span>\n    warning<span class=\"token operator\">:</span> nextWarning\n<span class=\"token punctuation\">}</span></code></pre></div><h3 id=\"configprovider-initlocales-locales\">ConfigProvider.initLocales(locales)<a href=\"#configprovider-initlocales-locales\" class=\"anchor\">#</a></h3><p>Config locales, together with method <code>ConfigProvider.setLanguage</code> to specify the language package</p>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\">ConfigProvider<span class=\"token punctuation\">.</span><span class=\"token function\">initLocales</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n    <span class=\"token string\">&apos;zh-cn&apos;</span><span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    <span class=\"token string\">&apos;en-us&apos;</span><span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span><span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><h3 id=\"configprovider-setlanguage-language\">ConfigProvider.setLanguage(language)<a href=\"#configprovider-setlanguage-language\" class=\"anchor\">#</a></h3><p>Set language, the parameter <code>language</code> needs to be one of the keys of <code>locales</code> which is the input of <code>ConfigProvider.initLocales</code>. <code>zh-cn</code> by default.</p>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\">ConfigProvider<span class=\"token punctuation\">.</span><span class=\"token function\">setLanguage</span><span class=\"token punctuation\">(</span><span class=\"token string\">&apos;zh-cn&apos;</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><h3 id=\"configprovider-setlocale-locale\">ConfigProvider.setLocale(locale)<a href=\"#configprovider-setlocale-locale\" class=\"anchor\">#</a></h3><p>Set language package directly.</p>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token comment\">// The effect is the same as using ConfigProvider.initLocales and ConfigProvider.setLanguage</span>\nConfigProvider<span class=\"token punctuation\">.</span><span class=\"token function\">setLocale</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n    DatePicker<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    Dialog<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span><span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><h3 id=\"configprovider-setdirection-dir\">ConfigProvider.setDirection(dir)<a href=\"#configprovider-setdirection-dir\" class=\"anchor\">#</a></h3><p>Set dir, when it is <code>rtl</code>, <code>dir=&quot;rtl&quot;</code> will be added on the DOM element of each component&apos;s root node.</p>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\">ConfigProvider<span class=\"token punctuation\">.</span><span class=\"token function\">setDirection</span><span class=\"token punctuation\">(</span><span class=\"token string\">&apos;rtl&apos;</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><h3 id=\"configprovider-getlocale\">ConfigProvider.getLocale()<a href=\"#configprovider-getlocale\" class=\"anchor\">#</a></h3><p>Return the setted language package.</p>\n<h3 id=\"configprovider-getlanguage\">ConfigProvider.getLanguage()<a href=\"#configprovider-getlanguage\" class=\"anchor\">#</a></h3><p>Return the language&apos;s name.</p>\n<h3 id=\"configprovider-getdirection\">ConfigProvider.getDirection()<a href=\"#configprovider-getdirection\" class=\"anchor\">#</a></h3><p>Return the direction.</p>\n<!-- api-extra-end -->\n<h2 id=\"note\">Note<a href=\"#note\" class=\"anchor\">#</a></h2><h3 id=\"reduce-moment-size-built-with-webpack\">Reduce moment size built with webpack<a href=\"#reduce-moment-size-built-with-webpack\" class=\"anchor\">#</a></h3><p>Next 1.x will use moment as its peerDependencies instead of dependencies, so the user needs to import the moment&apos;s cdn file moment-with-locales.js or the local moment module into his own application. For the latter, due to the moment has such code:  <code>require(&apos;./locale/&apos; + name)</code> to import locale files, if built with webpack, it will be packaged into all <a href=\"https://github.com/moment/moment/tree/develop/locale\" target=\"_blank\">locale files</a> to increase the size of files. There are two main solutions in the current community:</p>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">const</span> webpack <span class=\"token operator\">=</span> <span class=\"token function\">require</span><span class=\"token punctuation\">(</span><span class=\"token string\">&apos;webpack&apos;</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\nmodule<span class=\"token punctuation\">.</span>exports <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token comment\">// ...</span>\n    plugins<span class=\"token operator\">:</span> <span class=\"token punctuation\">[</span>\n    <span class=\"token comment\">// Package the specified language files</span>\n        <span class=\"token keyword\">new</span> <span class=\"token class-name\">webpack<span class=\"token punctuation\">.</span>ContextReplacementPlugin</span><span class=\"token punctuation\">(</span><span class=\"token regex\">/moment[\\/\\\\]locale$/</span><span class=\"token punctuation\">,</span> <span class=\"token regex\">/zh-cn|ja/</span><span class=\"token punctuation\">)</span>\n    <span class=\"token comment\">// Only package the language files referenced, and should add `import &apos;moment/locale/zh-cn&apos;;` in the application</span>\n    <span class=\"token comment\">// new webpack.IgnorePlugin(/^\\.\\/locale$/, /moment$/)</span>\n    <span class=\"token punctuation\">]</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span></code></pre></div><h3 id=\"add-displayname-for-the-custom-component\">Add displayName for the custom component<a href=\"#add-displayname-for-the-custom-component\" class=\"anchor\">#</a></h3><p>ConfigProvider use a Component&apos;s displayName or name to get its locale. However, the name of the function may be modified in the process of compression and uglifying. Therefore, if you want to support multi-language, you shoul add displayName to the component manually:</p>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">class</span> <span class=\"token class-name\">CustomComponent</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">static</span> displayName <span class=\"token operator\">=</span> <span class=\"token string\">&apos;CustomComponent&apos;</span><span class=\"token punctuation\">;</span>\n    <span class=\"token comment\">// ...</span>\n<span class=\"token punctuation\">}</span></code></pre></div><p>Or use <code>babel-plugin-transform-react-es6-displayname</code> to add displayName during compilation automatically.</p>\n<h3 id=\"get-the-internal-component-39-s-reference-of-the-hoc\">Get the internal component&apos;s reference of the HOC<a href=\"#get-the-internal-component-39-s-reference-of-the-hoc\" class=\"anchor\">#</a></h3><p>Due to the limit of the HOC itself, we can&apos;t get the reference of an internal component and call some of its internal methods as below:</p>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">class</span> <span class=\"token class-name\">App</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token function\">componentDidMount</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token comment\">// throw an error</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>refs<span class=\"token punctuation\">.</span>hoc<span class=\"token punctuation\">.</span><span class=\"token function\">someMethod</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">HOC</span></span> <span class=\"token attr-name\">ref</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">&quot;</span>hoc<span class=\"token punctuation\">&quot;</span></span> <span class=\"token punctuation\">/&gt;</span></span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span></code></pre></div><p>To solve this problem, we provide a method called getInstance of the HOC generated by calling the config method. You can call it as below:</p>\n<div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">class</span> <span class=\"token class-name\">App</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token function\">componentDidMount</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>refs<span class=\"token punctuation\">.</span>hoc<span class=\"token punctuation\">.</span><span class=\"token function\">getInstance</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">.</span><span class=\"token function\">someMethod</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">HOC</span></span> <span class=\"token attr-name\">ref</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">&quot;</span>hoc<span class=\"token punctuation\">&quot;</span></span> <span class=\"token punctuation\">/&gt;</span></span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span></code></pre></div>"}