{"title":"快捷调用","meta":{"title":"快捷调用","description":"\n<p>Dialog 提供 alert 和 confirm 的快掉调用方式，以及更底层的 show 方式。</p>\n","order":"5"},"codes":{"jsx":"import { Button, Dialog, ConfigProvider } from '@alifd/next';\n\nconst popupAlert = () => {\n    Dialog.alert({\n        title: 'Alert',\n        content: 'alert content alert content...',\n        okProps: {children: 'Custom OK' },\n        onOk: () => console.log('ok')\n    });\n};\n\nconst popupConfirm = () => {\n    Dialog.confirm({\n        title: 'Confirm',\n        content: 'confirm content confirm content...',\n        onOk: () => console.log('ok'),\n        onCancel: () => console.log('cancel')\n    });\n};\n\nconst popupShow = () => {\n    const dialog = Dialog.show({\n        title: 'Custom',\n        content: 'custom content custom content...',\n        footer: (\n            <Button warning type=\"primary\" onClick={() => dialog.hide()}>\n                Custom button\n            </Button>\n        )\n    });\n};\n\nconst popupCustomIcon = () => {\n    Dialog.confirm({\n        title: 'Confirm',\n        content: 'set icon as \"warning\" ',\n        messageProps:{\n            type: 'warning'\n        },\n        onOk: () => console.log('ok'),\n        onCancel: () => console.log('cancel')\n    });\n};\n\nReactDOM.render(\n    <ConfigProvider locale={{ Dialog: { ok: 'OK', cancel: 'Cancel' } }}>\n        <span>\n            <Button onClick={popupAlert}>Alert</Button> &nbsp;\n            <Button onClick={popupConfirm}>Confirm</Button> &nbsp;\n            <Button onClick={popupShow}>Show</Button> &nbsp;\n            <Button onClick={popupCustomIcon}>Custom Icon</Button>\n        </span>\n    </ConfigProvider>,\n    mountNode\n);\n"},"body":"\n\n````jsx\nimport { Button, Dialog, ConfigProvider } from '@alifd/next';\n\nconst popupAlert = () => {\n    Dialog.alert({\n        title: 'Alert',\n        content: 'alert content alert content...',\n        okProps: {children: 'Custom OK' },\n        onOk: () => console.log('ok')\n    });\n};\n\nconst popupConfirm = () => {\n    Dialog.confirm({\n        title: 'Confirm',\n        content: 'confirm content confirm content...',\n        onOk: () => console.log('ok'),\n        onCancel: () => console.log('cancel')\n    });\n};\n\nconst popupShow = () => {\n    const dialog = Dialog.show({\n        title: 'Custom',\n        content: 'custom content custom content...',\n        footer: (\n            <Button warning type=\"primary\" onClick={() => dialog.hide()}>\n                Custom button\n            </Button>\n        )\n    });\n};\n\nconst popupCustomIcon = () => {\n    Dialog.confirm({\n        title: 'Confirm',\n        content: 'set icon as \"warning\" ',\n        messageProps:{\n            type: 'warning'\n        },\n        onOk: () => console.log('ok'),\n        onCancel: () => console.log('cancel')\n    });\n};\n\nReactDOM.render(\n    <ConfigProvider locale={{ Dialog: { ok: 'OK', cancel: 'Cancel' } }}>\n        <span>\n            <Button onClick={popupAlert}>Alert</Button> &nbsp;\n            <Button onClick={popupConfirm}>Confirm</Button> &nbsp;\n            <Button onClick={popupShow}>Show</Button> &nbsp;\n            <Button onClick={popupCustomIcon}>Custom Icon</Button>\n        </span>\n    </ConfigProvider>,\n    mountNode\n);\n````","html":"<script>(function(){'use strict';\n\nvar _next = require('@alifd/next');\n\nvar popupAlert = function popupAlert() {\n    _next.Dialog.alert({\n        title: 'Alert',\n        content: 'alert content alert content...',\n        okProps: { children: 'Custom OK' },\n        onOk: function onOk() {\n            return console.log('ok');\n        }\n    });\n};\n\nvar popupConfirm = function popupConfirm() {\n    _next.Dialog.confirm({\n        title: 'Confirm',\n        content: 'confirm content confirm content...',\n        onOk: function onOk() {\n            return console.log('ok');\n        },\n        onCancel: function onCancel() {\n            return console.log('cancel');\n        }\n    });\n};\n\nvar popupShow = function popupShow() {\n    var dialog = _next.Dialog.show({\n        title: 'Custom',\n        content: 'custom content custom content...',\n        footer: React.createElement(\n            _next.Button,\n            { warning: true, type: 'primary', onClick: function onClick() {\n                    return dialog.hide();\n                } },\n            'Custom button'\n        )\n    });\n};\n\nvar popupCustomIcon = function popupCustomIcon() {\n    _next.Dialog.confirm({\n        title: 'Confirm',\n        content: 'set icon as \"warning\" ',\n        messageProps: {\n            type: 'warning'\n        },\n        onOk: function onOk() {\n            return console.log('ok');\n        },\n        onCancel: function onCancel() {\n            return console.log('cancel');\n        }\n    });\n};\n\nReactDOM.render(React.createElement(\n    _next.ConfigProvider,\n    { locale: { Dialog: { ok: 'OK', cancel: 'Cancel' } } },\n    React.createElement(\n        'span',\n        null,\n        React.createElement(\n            _next.Button,\n            { onClick: popupAlert },\n            'Alert'\n        ),\n        ' \\xA0',\n        React.createElement(\n            _next.Button,\n            { onClick: popupConfirm },\n            'Confirm'\n        ),\n        ' \\xA0',\n        React.createElement(\n            _next.Button,\n            { onClick: popupShow },\n            'Show'\n        ),\n        ' \\xA0',\n        React.createElement(\n            _next.Button,\n            { onClick: popupCustomIcon },\n            'Custom Icon'\n        )\n    )\n), mountNode);})()</script><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> Button<span class=\"token punctuation\">,</span> Dialog<span class=\"token punctuation\">,</span> ConfigProvider <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next'</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> <span class=\"token function-variable function\">popupAlert</span> <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n    Dialog<span class=\"token punctuation\">.</span><span class=\"token function\">alert</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n        title<span class=\"token operator\">:</span> <span class=\"token string\">'Alert'</span><span class=\"token punctuation\">,</span>\n        content<span class=\"token operator\">:</span> <span class=\"token string\">'alert content alert content...'</span><span class=\"token punctuation\">,</span>\n        okProps<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>children<span class=\"token operator\">:</span> <span class=\"token string\">'Custom OK'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token function-variable function\">onOk</span><span class=\"token operator\">:</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> console<span class=\"token punctuation\">.</span><span class=\"token function\">log</span><span class=\"token punctuation\">(</span><span class=\"token string\">'ok'</span><span class=\"token punctuation\">)</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> <span class=\"token function-variable function\">popupConfirm</span> <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n    Dialog<span class=\"token punctuation\">.</span><span class=\"token function\">confirm</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n        title<span class=\"token operator\">:</span> <span class=\"token string\">'Confirm'</span><span class=\"token punctuation\">,</span>\n        content<span class=\"token operator\">:</span> <span class=\"token string\">'confirm content confirm content...'</span><span class=\"token punctuation\">,</span>\n        <span class=\"token function-variable function\">onOk</span><span class=\"token operator\">:</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> console<span class=\"token punctuation\">.</span><span class=\"token function\">log</span><span class=\"token punctuation\">(</span><span class=\"token string\">'ok'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">,</span>\n        <span class=\"token function-variable function\">onCancel</span><span class=\"token operator\">:</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> console<span class=\"token punctuation\">.</span><span class=\"token function\">log</span><span class=\"token punctuation\">(</span><span class=\"token string\">'cancel'</span><span class=\"token punctuation\">)</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> <span class=\"token function-variable function\">popupShow</span> <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">const</span> dialog <span class=\"token operator\">=</span> Dialog<span class=\"token punctuation\">.</span><span class=\"token function\">show</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n        title<span class=\"token operator\">:</span> <span class=\"token string\">'Custom'</span><span class=\"token punctuation\">,</span>\n        content<span class=\"token operator\">:</span> <span class=\"token string\">'custom content custom content...'</span><span class=\"token punctuation\">,</span>\n        footer<span class=\"token operator\">:</span> <span class=\"token punctuation\">(</span>\n            <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">warning</span> <span class=\"token attr-name\">type</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>primary<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> dialog<span class=\"token punctuation\">.</span><span class=\"token function\">hide</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                Custom button\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span>\n        <span class=\"token punctuation\">)</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> <span class=\"token function-variable function\">popupCustomIcon</span> <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n    Dialog<span class=\"token punctuation\">.</span><span class=\"token function\">confirm</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n        title<span class=\"token operator\">:</span> <span class=\"token string\">'Confirm'</span><span class=\"token punctuation\">,</span>\n        content<span class=\"token operator\">:</span> <span class=\"token string\">'set icon as \"warning\" '</span><span class=\"token punctuation\">,</span>\n        messageProps<span class=\"token operator\">:</span><span class=\"token punctuation\">{</span>\n            type<span class=\"token operator\">:</span> <span class=\"token string\">'warning'</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token function-variable function\">onOk</span><span class=\"token operator\">:</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> console<span class=\"token punctuation\">.</span><span class=\"token function\">log</span><span class=\"token punctuation\">(</span><span class=\"token string\">'ok'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">,</span>\n        <span class=\"token function-variable function\">onCancel</span><span class=\"token operator\">:</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> console<span class=\"token punctuation\">.</span><span class=\"token function\">log</span><span class=\"token punctuation\">(</span><span class=\"token string\">'cancel'</span><span class=\"token punctuation\">)</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\nReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span>\n    <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">ConfigProvider</span></span> <span class=\"token attr-name\">locale</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span> Dialog<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span> ok<span class=\"token operator\">:</span> <span class=\"token string\">'OK'</span><span class=\"token punctuation\">,</span> cancel<span class=\"token operator\">:</span> <span class=\"token string\">'Cancel'</span> <span class=\"token punctuation\">}</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>span</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>popupAlert<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Alert</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\"> &amp;nbsp;\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>popupConfirm<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Confirm</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\"> &amp;nbsp;\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>popupShow<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Show</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\"> &amp;nbsp;\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>popupCustomIcon<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Custom Icon</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>span</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">ConfigProvider</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">,</span>\n    mountNode\n<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div>"}