{"title":"use Field","meta":{"title":"use Field","description":"\n<p>Complex functions can be realized with <code>Field</code></p>\n","order":"10"},"codes":{"jsx":"import { Form, Input, Radio, Field, Button } from '@alifd/next';\n\n\nconst FormItem = Form.Item;\nconst RadioGroup = Radio.Group;\n\nconst formItemLayout = {\n    labelCol: {\n        span: 6\n    },\n    wrapperCol: {\n        span: 14\n    }\n};\n\nclass BasicDemo extends React.Component {\n    field = new Field(this);\n\n    userExists(rule, value) {\n        return new Promise((resolve, reject) => {\n            if (!value) {\n                resolve();\n            } else {\n                setTimeout(() => {\n                    if (value === 'frank') {\n                        reject([new Error('Sorry, this username is already occupied.')]);\n                    } else {\n                        resolve();\n                    }\n                }, 500);\n            }\n        });\n    }\n\n    checkPass(rule, value, callback) {\n        const { validate } = this.field;\n        if (value) {\n            validate(['rePasswd']);\n        }\n        callback();\n    }\n\n    checkPass2(rule, value, callback) {\n        const { getValue } = this.field;\n        if (value && value !== getValue('passwd')) {\n            return callback('Inconsistent password input twice!');\n        } else {\n            return callback();\n        }\n    }\n\n    validate = () => {\n        this.field.validate(['sex']);\n    }\n\n    render() {\n        const {getState, getValue, getError} = this.field;\n\n        return (\n            <Form {...formItemLayout} field={this.field}>\n                <FormItem\n                    label=\"Username:\"\n                    hasFeedback\n                    required\n                    validator={this.userExists.bind(this)}\n                    help={getState('username') === 'loading' ? 'Checking ...' : getError('username')}\n                >\n                    <Input placeholder=\"Input frank\" name=\"username\" />\n                    <p>Hello {getValue('username')}</p>\n                </FormItem>\n\n                <FormItem\n                    label=\"Password:\"\n                    hasFeedback\n                    required\n                    requiredMessage=\"Please enter password\"\n                    validator={this.checkPass.bind(this)}\n                >\n                    <Input htmlType=\"password\" name=\"passwd\" />\n                </FormItem>\n\n                <FormItem\n                    label=\"Check your password:\"\n                    hasFeedback\n                    required\n                    requiredMessage=\"Enter your password again\"\n                    validator={this.checkPass2.bind(this)}\n                >\n                    <Input htmlType=\"password\" placeholder=\"Enter the same password twice\" name=\"rePasswd\" />\n                </FormItem>\n\n                <FormItem\n                    label=\"Gender:\"\n                    hasFeedback\n                    required\n                    requiredMessage=\"Please select your gender\"\n                >\n                    <RadioGroup name=\"sex\" >\n                        <Radio value=\"male\">Male</Radio>\n                        <Radio value=\"female\">Female</Radio>\n                    </RadioGroup>\n                </FormItem>\n\n                <FormItem wrapperCol={{ offset: 6 }} >\n                    <Button onClick={this.validate}>Validate by Field</Button>\n                    <Form.Submit validate type=\"primary\" onClick={(v, e) => console.log(v, e)} style={{margin: '0 10px'}}>Submit</Form.Submit>\n                    <Form.Reset >Reset</Form.Reset>\n                </FormItem>\n            </Form>\n        );\n    }\n}\n\n\nReactDOM.render(<BasicDemo />, mountNode);\n"},"body":"\n````jsx\nimport { Form, Input, Radio, Field, Button } from '@alifd/next';\n\n\nconst FormItem = Form.Item;\nconst RadioGroup = Radio.Group;\n\nconst formItemLayout = {\n    labelCol: {\n        span: 6\n    },\n    wrapperCol: {\n        span: 14\n    }\n};\n\nclass BasicDemo extends React.Component {\n    field = new Field(this);\n\n    userExists(rule, value) {\n        return new Promise((resolve, reject) => {\n            if (!value) {\n                resolve();\n            } else {\n                setTimeout(() => {\n                    if (value === 'frank') {\n                        reject([new Error('Sorry, this username is already occupied.')]);\n                    } else {\n                        resolve();\n                    }\n                }, 500);\n            }\n        });\n    }\n\n    checkPass(rule, value, callback) {\n        const { validate } = this.field;\n        if (value) {\n            validate(['rePasswd']);\n        }\n        callback();\n    }\n\n    checkPass2(rule, value, callback) {\n        const { getValue } = this.field;\n        if (value && value !== getValue('passwd')) {\n            return callback('Inconsistent password input twice!');\n        } else {\n            return callback();\n        }\n    }\n\n    validate = () => {\n        this.field.validate(['sex']);\n    }\n\n    render() {\n        const {getState, getValue, getError} = this.field;\n\n        return (\n            <Form {...formItemLayout} field={this.field}>\n                <FormItem\n                    label=\"Username:\"\n                    hasFeedback\n                    required\n                    validator={this.userExists.bind(this)}\n                    help={getState('username') === 'loading' ? 'Checking ...' : getError('username')}\n                >\n                    <Input placeholder=\"Input frank\" name=\"username\" />\n                    <p>Hello {getValue('username')}</p>\n                </FormItem>\n\n                <FormItem\n                    label=\"Password:\"\n                    hasFeedback\n                    required\n                    requiredMessage=\"Please enter password\"\n                    validator={this.checkPass.bind(this)}\n                >\n                    <Input htmlType=\"password\" name=\"passwd\" />\n                </FormItem>\n\n                <FormItem\n                    label=\"Check your password:\"\n                    hasFeedback\n                    required\n                    requiredMessage=\"Enter your password again\"\n                    validator={this.checkPass2.bind(this)}\n                >\n                    <Input htmlType=\"password\" placeholder=\"Enter the same password twice\" name=\"rePasswd\" />\n                </FormItem>\n\n                <FormItem\n                    label=\"Gender:\"\n                    hasFeedback\n                    required\n                    requiredMessage=\"Please select your gender\"\n                >\n                    <RadioGroup name=\"sex\" >\n                        <Radio value=\"male\">Male</Radio>\n                        <Radio value=\"female\">Female</Radio>\n                    </RadioGroup>\n                </FormItem>\n\n                <FormItem wrapperCol={{ offset: 6 }} >\n                    <Button onClick={this.validate}>Validate by Field</Button>\n                    <Form.Submit validate type=\"primary\" onClick={(v, e) => console.log(v, e)} style={{margin: '0 10px'}}>Submit</Form.Submit>\n                    <Form.Reset >Reset</Form.Reset>\n                </FormItem>\n            </Form>\n        );\n    }\n}\n\n\nReactDOM.render(<BasicDemo />, mountNode);\n````","html":"<script>(function(){'use strict';\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nvar _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();\n\nvar _next = require('@alifd/next');\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return call && (typeof call === \"object\" || typeof call === \"function\") ? call : self; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function, not \" + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }\n\nvar FormItem = _next.Form.Item;\nvar RadioGroup = _next.Radio.Group;\n\nvar formItemLayout = {\n    labelCol: {\n        span: 6\n    },\n    wrapperCol: {\n        span: 14\n    }\n};\n\nvar BasicDemo = function (_React$Component) {\n    _inherits(BasicDemo, _React$Component);\n\n    function BasicDemo() {\n        var _ref;\n\n        var _temp, _this, _ret;\n\n        _classCallCheck(this, BasicDemo);\n\n        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {\n            args[_key] = arguments[_key];\n        }\n\n        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = BasicDemo.__proto__ || Object.getPrototypeOf(BasicDemo)).call.apply(_ref, [this].concat(args))), _this), _this.field = new _next.Field(_this), _this.validate = function () {\n            _this.field.validate(['sex']);\n        }, _temp), _possibleConstructorReturn(_this, _ret);\n    }\n\n    _createClass(BasicDemo, [{\n        key: 'userExists',\n        value: function userExists(rule, value) {\n            return new Promise(function (resolve, reject) {\n                if (!value) {\n                    resolve();\n                } else {\n                    setTimeout(function () {\n                        if (value === 'frank') {\n                            reject([new Error('Sorry, this username is already occupied.')]);\n                        } else {\n                            resolve();\n                        }\n                    }, 500);\n                }\n            });\n        }\n    }, {\n        key: 'checkPass',\n        value: function checkPass(rule, value, callback) {\n            var validate = this.field.validate;\n\n            if (value) {\n                validate(['rePasswd']);\n            }\n            callback();\n        }\n    }, {\n        key: 'checkPass2',\n        value: function checkPass2(rule, value, callback) {\n            var getValue = this.field.getValue;\n\n            if (value && value !== getValue('passwd')) {\n                return callback('Inconsistent password input twice!');\n            } else {\n                return callback();\n            }\n        }\n    }, {\n        key: 'render',\n        value: function render() {\n            var _field = this.field,\n                getState = _field.getState,\n                getValue = _field.getValue,\n                getError = _field.getError;\n\n\n            return React.createElement(\n                _next.Form,\n                _extends({}, formItemLayout, { field: this.field }),\n                React.createElement(\n                    FormItem,\n                    {\n                        label: 'Username:',\n                        hasFeedback: true,\n                        required: true,\n                        validator: this.userExists.bind(this),\n                        help: getState('username') === 'loading' ? 'Checking ...' : getError('username')\n                    },\n                    React.createElement(_next.Input, { placeholder: 'Input frank', name: 'username' }),\n                    React.createElement(\n                        'p',\n                        null,\n                        'Hello ',\n                        getValue('username')\n                    )\n                ),\n                React.createElement(\n                    FormItem,\n                    {\n                        label: 'Password:',\n                        hasFeedback: true,\n                        required: true,\n                        requiredMessage: 'Please enter password',\n                        validator: this.checkPass.bind(this)\n                    },\n                    React.createElement(_next.Input, { htmlType: 'password', name: 'passwd' })\n                ),\n                React.createElement(\n                    FormItem,\n                    {\n                        label: 'Check your password:',\n                        hasFeedback: true,\n                        required: true,\n                        requiredMessage: 'Enter your password again',\n                        validator: this.checkPass2.bind(this)\n                    },\n                    React.createElement(_next.Input, { htmlType: 'password', placeholder: 'Enter the same password twice', name: 'rePasswd' })\n                ),\n                React.createElement(\n                    FormItem,\n                    {\n                        label: 'Gender:',\n                        hasFeedback: true,\n                        required: true,\n                        requiredMessage: 'Please select your gender'\n                    },\n                    React.createElement(\n                        RadioGroup,\n                        { name: 'sex' },\n                        React.createElement(\n                            _next.Radio,\n                            { value: 'male' },\n                            'Male'\n                        ),\n                        React.createElement(\n                            _next.Radio,\n                            { value: 'female' },\n                            'Female'\n                        )\n                    )\n                ),\n                React.createElement(\n                    FormItem,\n                    { wrapperCol: { offset: 6 } },\n                    React.createElement(\n                        _next.Button,\n                        { onClick: this.validate },\n                        'Validate by Field'\n                    ),\n                    React.createElement(\n                        _next.Form.Submit,\n                        { validate: true, type: 'primary', onClick: function onClick(v, e) {\n                                return console.log(v, e);\n                            }, style: { margin: '0 10px' } },\n                        'Submit'\n                    ),\n                    React.createElement(\n                        _next.Form.Reset,\n                        null,\n                        'Reset'\n                    )\n                )\n            );\n        }\n    }]);\n\n    return BasicDemo;\n}(React.Component);\n\nReactDOM.render(React.createElement(BasicDemo, null), mountNode);})()</script><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> Form<span class=\"token punctuation\">,</span> Input<span class=\"token punctuation\">,</span> Radio<span class=\"token punctuation\">,</span> Field<span class=\"token punctuation\">,</span> Button <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next'</span><span class=\"token punctuation\">;</span>\n\n\n<span class=\"token keyword\">const</span> FormItem <span class=\"token operator\">=</span> Form<span class=\"token punctuation\">.</span>Item<span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">const</span> RadioGroup <span class=\"token operator\">=</span> Radio<span class=\"token punctuation\">.</span>Group<span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> formItemLayout <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n    labelCol<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n        span<span class=\"token operator\">:</span> <span class=\"token number\">6</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    wrapperCol<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n        span<span class=\"token operator\">:</span> <span class=\"token number\">14</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">BasicDemo</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    field <span class=\"token operator\">=</span> <span class=\"token keyword\">new</span> <span class=\"token class-name\">Field</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token function\">userExists</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">rule<span class=\"token punctuation\">,</span> value</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token keyword\">new</span> <span class=\"token class-name\">Promise</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">resolve<span class=\"token punctuation\">,</span> reject</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n            <span class=\"token keyword\">if</span> <span class=\"token punctuation\">(</span><span class=\"token operator\">!</span>value<span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n                <span class=\"token function\">resolve</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n            <span class=\"token punctuation\">}</span> <span class=\"token keyword\">else</span> <span class=\"token punctuation\">{</span>\n                <span class=\"token function\">setTimeout</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n                    <span class=\"token keyword\">if</span> <span class=\"token punctuation\">(</span>value <span class=\"token operator\">===</span> <span class=\"token string\">'frank'</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n                        <span class=\"token function\">reject</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">[</span><span class=\"token keyword\">new</span> <span class=\"token class-name\">Error</span><span class=\"token punctuation\">(</span><span class=\"token string\">'Sorry, this username is already occupied.'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n                    <span class=\"token punctuation\">}</span> <span class=\"token keyword\">else</span> <span class=\"token punctuation\">{</span>\n                        <span class=\"token function\">resolve</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n                    <span class=\"token punctuation\">}</span>\n                <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span> <span class=\"token number\">500</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n            <span class=\"token punctuation\">}</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">checkPass</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">rule<span class=\"token punctuation\">,</span> value<span class=\"token punctuation\">,</span> callback</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> validate <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>field<span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">if</span> <span class=\"token punctuation\">(</span>value<span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n            <span class=\"token function\">validate</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">[</span><span class=\"token string\">'rePasswd'</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n        <span class=\"token punctuation\">}</span>\n        <span class=\"token function\">callback</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">checkPass2</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">rule<span class=\"token punctuation\">,</span> value<span class=\"token punctuation\">,</span> callback</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> getValue <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>field<span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">if</span> <span class=\"token punctuation\">(</span>value <span class=\"token operator\">&amp;&amp;</span> value <span class=\"token operator\">!==</span> <span class=\"token function\">getValue</span><span class=\"token punctuation\">(</span><span class=\"token string\">'passwd'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n            <span class=\"token keyword\">return</span> <span class=\"token function\">callback</span><span class=\"token punctuation\">(</span><span class=\"token string\">'Inconsistent password input twice!'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n        <span class=\"token punctuation\">}</span> <span class=\"token keyword\">else</span> <span class=\"token punctuation\">{</span>\n            <span class=\"token keyword\">return</span> <span class=\"token function\">callback</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n        <span class=\"token punctuation\">}</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function-variable function\">validate</span> <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>field<span class=\"token punctuation\">.</span><span class=\"token function\">validate</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">[</span><span class=\"token string\">'sex'</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span>getState<span class=\"token punctuation\">,</span> getValue<span class=\"token punctuation\">,</span> getError<span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>field<span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span>\n            <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Form</span></span> <span class=\"token spread\"><span class=\"token punctuation\">{</span><span class=\"token punctuation\">...</span><span class=\"token attr-value\">formItemLayout</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">field</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>field<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">FormItem</span></span>\n                    <span class=\"token attr-name\">label</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Username:<span class=\"token punctuation\">\"</span></span>\n                    <span class=\"token attr-name\">hasFeedback</span>\n                    <span class=\"token attr-name\">required</span>\n                    <span class=\"token attr-name\">validator</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">userExists</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span>\n                    <span class=\"token attr-name\">help</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token function\">getState</span><span class=\"token punctuation\">(</span><span class=\"token string\">'username'</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">===</span> <span class=\"token string\">'loading'</span> <span class=\"token operator\">?</span> <span class=\"token string\">'Checking ...'</span> <span class=\"token operator\">:</span> <span class=\"token function\">getError</span><span class=\"token punctuation\">(</span><span class=\"token string\">'username'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span>\n                <span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Input</span></span> <span class=\"token attr-name\">placeholder</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Input frank<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">name</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>username<span class=\"token punctuation\">\"</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>p</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Hello </span><span class=\"token punctuation\">{</span><span class=\"token function\">getValue</span><span class=\"token punctuation\">(</span><span class=\"token string\">'username'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>p</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">FormItem</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">FormItem</span></span>\n                    <span class=\"token attr-name\">label</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Password:<span class=\"token punctuation\">\"</span></span>\n                    <span class=\"token attr-name\">hasFeedback</span>\n                    <span class=\"token attr-name\">required</span>\n                    <span class=\"token attr-name\">requiredMessage</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Please enter password<span class=\"token punctuation\">\"</span></span>\n                    <span class=\"token attr-name\">validator</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">checkPass</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span>\n                <span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Input</span></span> <span class=\"token attr-name\">htmlType</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>password<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">name</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>passwd<span class=\"token punctuation\">\"</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">FormItem</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">FormItem</span></span>\n                    <span class=\"token attr-name\">label</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Check your password:<span class=\"token punctuation\">\"</span></span>\n                    <span class=\"token attr-name\">hasFeedback</span>\n                    <span class=\"token attr-name\">required</span>\n                    <span class=\"token attr-name\">requiredMessage</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Enter your password again<span class=\"token punctuation\">\"</span></span>\n                    <span class=\"token attr-name\">validator</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">checkPass2</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span>\n                <span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Input</span></span> <span class=\"token attr-name\">htmlType</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>password<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">placeholder</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Enter the same password twice<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">name</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>rePasswd<span class=\"token punctuation\">\"</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">FormItem</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">FormItem</span></span>\n                    <span class=\"token attr-name\">label</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Gender:<span class=\"token punctuation\">\"</span></span>\n                    <span class=\"token attr-name\">hasFeedback</span>\n                    <span class=\"token attr-name\">required</span>\n                    <span class=\"token attr-name\">requiredMessage</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Please select your gender<span class=\"token punctuation\">\"</span></span>\n                <span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">RadioGroup</span></span> <span class=\"token attr-name\">name</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>sex<span class=\"token punctuation\">\"</span></span> <span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Radio</span></span> <span class=\"token attr-name\">value</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>male<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Male</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Radio</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Radio</span></span> <span class=\"token attr-name\">value</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>female<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Female</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Radio</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">RadioGroup</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">FormItem</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">FormItem</span></span> <span class=\"token attr-name\">wrapperCol</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span> offset<span class=\"token operator\">:</span> <span class=\"token number\">6</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>validate<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Validate by Field</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Form.Submit</span></span> <span class=\"token attr-name\">validate</span> <span class=\"token attr-name\">type</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>primary<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">v<span class=\"token punctuation\">,</span> e</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> console<span class=\"token punctuation\">.</span><span class=\"token function\">log</span><span class=\"token punctuation\">(</span>v<span class=\"token punctuation\">,</span> e<span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">style</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span>margin<span class=\"token operator\">:</span> <span class=\"token string\">'0 10px'</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Submit</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Form.Submit</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Form.Reset</span></span> <span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Reset</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Form.Reset</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">FormItem</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Form</span></span><span class=\"token punctuation\">></span></span>\n        <span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\n\n\nReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">BasicDemo</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token punctuation\">,</span> mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div>"}