{"title":"Specify the Error Message Position","meta":{"title":"Specify the Error Message Position","description":"\n<p>Combine <code>componentWillReceiveProps</code> with setErrors<code>in</code>redux`</p>\n<p>If you need to specify the error message position, you can make <code>help=&quot;&quot;</code> and place the error display yourself.</p>\n","order":"13"},"codes":{"jsx":"import { Form, Input, Button, Field } from '@alifd/next';\nimport { combineReducers, createStore } from 'redux';\nimport { Provider, connect } from 'react-redux';\n\n\n\nconst initState = {\n    values: {email: '', username: 'xiachi'},\n    errors: {}\n};\n\nfunction formReducer(state = initState, action) {\n    switch (action.type) {\n        case 'save_fields':\n            return {\n                ...state,\n                values: {\n                    ...state.values,\n                    ...action.values\n                }\n            };\n        case 'set_errors':\n            return {\n                ...state,\n                errors: {\n                    ...state.errors,\n                    ...action.errors\n                }\n            };\n        default:\n            return state;\n    }\n}\n\nclass FormDemo extends React.Component {\n    constructor(props) {\n        super(props);\n\n        this.field = new Field(this, {\n            onChange: (name, value) => {\n                console.log('onChange', name, value, this.field.getError(name));\n                this.props.dispatch({\n                    type: 'save_fields',\n                    values: {\n                        [name]: value\n                    }\n                });\n                this.props.dispatch({\n                    type: 'set_errors',\n                    errors: {\n                        [name]: this.field.getError(name)\n                    }\n                });\n            }\n        });\n    }\n\n    componentWillReceiveProps(nextProps) {\n        this.field.setValues(nextProps.formData.values);\n        this.field.setErrors(nextProps.formData.errors);\n    }\n\n    setEmail() {\n        this.props.dispatch({\n            type: 'save_fields',\n            values: {\n                email: 'qq@gmail.com'\n            }\n        });\n    }\n\n    setName() {\n        this.props.dispatch({\n            type: 'save_fields',\n            values: {\n                username: 'frank'\n            }\n        });\n    }\n\n    setError() {\n        this.props.dispatch({\n            type: 'set_errors',\n            errors: {\n                email: 'Error message from remote'\n            }\n        });\n    }\n\n    setErrors() {\n        this.props.dispatch({\n            type: 'set_errors',\n            errors: {\n                email: 'A-Error message from remote',\n                username: 'B-Error message from remote'\n            }\n        });\n    }\n\n    render() {\n        return (<Form field={this.field}>\n            <Form.Item required format=\"email\">\n                <Input name=\"email\"/>\n            </Form.Item>\n            <Form.Item help=\"\" required requiredMessage=\"required\">\n                <Input name=\"username\" defaultValue={this.props.formData.values.username} />\n                <p style={{color: 'blue'}}>{this.field.getError('username')}</p>\n            </Form.Item>\n\n            <p>email: {this.props.email && this.props.email.value}</p>\n            <Button onClick={this.setEmail.bind(this)}>setEmail</Button>\n            <Button onClick={this.setName.bind(this)}>setName</Button>\n            <Button onClick={this.setError.bind(this)}>setError</Button>\n            <Button onClick={this.setErrors.bind(this)}>setErrors</Button>\n            <Button onClick={() => this.field.reset()}>reset</Button>\n        </Form>);\n    }\n}\n\n\nconst ReduxFormDemo = connect((state) => {\n    return {\n        formData: state.formReducer\n    };\n})(FormDemo);\n\nconst store = createStore(combineReducers({\n    formReducer\n}));\n\nReactDOM.render(<Provider store={store}>\n    <div>\n        <ReduxFormDemo />\n    </div>\n</Provider>, mountNode);\n"},"body":"\n````jsx\nimport { Form, Input, Button, Field } from '@alifd/next';\nimport { combineReducers, createStore } from 'redux';\nimport { Provider, connect } from 'react-redux';\n\n\n\nconst initState = {\n    values: {email: '', username: 'xiachi'},\n    errors: {}\n};\n\nfunction formReducer(state = initState, action) {\n    switch (action.type) {\n        case 'save_fields':\n            return {\n                ...state,\n                values: {\n                    ...state.values,\n                    ...action.values\n                }\n            };\n        case 'set_errors':\n            return {\n                ...state,\n                errors: {\n                    ...state.errors,\n                    ...action.errors\n                }\n            };\n        default:\n            return state;\n    }\n}\n\nclass FormDemo extends React.Component {\n    constructor(props) {\n        super(props);\n\n        this.field = new Field(this, {\n            onChange: (name, value) => {\n                console.log('onChange', name, value, this.field.getError(name));\n                this.props.dispatch({\n                    type: 'save_fields',\n                    values: {\n                        [name]: value\n                    }\n                });\n                this.props.dispatch({\n                    type: 'set_errors',\n                    errors: {\n                        [name]: this.field.getError(name)\n                    }\n                });\n            }\n        });\n    }\n\n    componentWillReceiveProps(nextProps) {\n        this.field.setValues(nextProps.formData.values);\n        this.field.setErrors(nextProps.formData.errors);\n    }\n\n    setEmail() {\n        this.props.dispatch({\n            type: 'save_fields',\n            values: {\n                email: 'qq@gmail.com'\n            }\n        });\n    }\n\n    setName() {\n        this.props.dispatch({\n            type: 'save_fields',\n            values: {\n                username: 'frank'\n            }\n        });\n    }\n\n    setError() {\n        this.props.dispatch({\n            type: 'set_errors',\n            errors: {\n                email: 'Error message from remote'\n            }\n        });\n    }\n\n    setErrors() {\n        this.props.dispatch({\n            type: 'set_errors',\n            errors: {\n                email: 'A-Error message from remote',\n                username: 'B-Error message from remote'\n            }\n        });\n    }\n\n    render() {\n        return (<Form field={this.field}>\n            <Form.Item required format=\"email\">\n                <Input name=\"email\"/>\n            </Form.Item>\n            <Form.Item help=\"\" required requiredMessage=\"required\">\n                <Input name=\"username\" defaultValue={this.props.formData.values.username} />\n                <p style={{color: 'blue'}}>{this.field.getError('username')}</p>\n            </Form.Item>\n\n            <p>email: {this.props.email && this.props.email.value}</p>\n            <Button onClick={this.setEmail.bind(this)}>setEmail</Button>\n            <Button onClick={this.setName.bind(this)}>setName</Button>\n            <Button onClick={this.setError.bind(this)}>setError</Button>\n            <Button onClick={this.setErrors.bind(this)}>setErrors</Button>\n            <Button onClick={() => this.field.reset()}>reset</Button>\n        </Form>);\n    }\n}\n\n\nconst ReduxFormDemo = connect((state) => {\n    return {\n        formData: state.formReducer\n    };\n})(FormDemo);\n\nconst store = createStore(combineReducers({\n    formReducer\n}));\n\nReactDOM.render(<Provider store={store}>\n    <div>\n        <ReduxFormDemo />\n    </div>\n</Provider>, mountNode);\n````","html":"<script>(function(){'use strict';\n\nvar _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nvar _next = require('@alifd/next');\n\nvar _redux = require('redux');\n\nvar _reactRedux = require('react-redux');\n\nfunction _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return call && (typeof call === \"object\" || typeof call === \"function\") ? call : self; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function, not \" + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }\n\nvar initState = {\n    values: { email: '', username: 'xiachi' },\n    errors: {}\n};\n\nfunction formReducer() {\n    var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initState;\n    var action = arguments[1];\n\n    switch (action.type) {\n        case 'save_fields':\n            return _extends({}, state, {\n                values: _extends({}, state.values, action.values)\n            });\n        case 'set_errors':\n            return _extends({}, state, {\n                errors: _extends({}, state.errors, action.errors)\n            });\n        default:\n            return state;\n    }\n}\n\nvar FormDemo = function (_React$Component) {\n    _inherits(FormDemo, _React$Component);\n\n    function FormDemo(props) {\n        _classCallCheck(this, FormDemo);\n\n        var _this = _possibleConstructorReturn(this, (FormDemo.__proto__ || Object.getPrototypeOf(FormDemo)).call(this, props));\n\n        _this.field = new _next.Field(_this, {\n            onChange: function onChange(name, value) {\n                console.log('onChange', name, value, _this.field.getError(name));\n                _this.props.dispatch({\n                    type: 'save_fields',\n                    values: _defineProperty({}, name, value)\n                });\n                _this.props.dispatch({\n                    type: 'set_errors',\n                    errors: _defineProperty({}, name, _this.field.getError(name))\n                });\n            }\n        });\n        return _this;\n    }\n\n    _createClass(FormDemo, [{\n        key: 'componentWillReceiveProps',\n        value: function componentWillReceiveProps(nextProps) {\n            this.field.setValues(nextProps.formData.values);\n            this.field.setErrors(nextProps.formData.errors);\n        }\n    }, {\n        key: 'setEmail',\n        value: function setEmail() {\n            this.props.dispatch({\n                type: 'save_fields',\n                values: {\n                    email: 'qq@gmail.com'\n                }\n            });\n        }\n    }, {\n        key: 'setName',\n        value: function setName() {\n            this.props.dispatch({\n                type: 'save_fields',\n                values: {\n                    username: 'frank'\n                }\n            });\n        }\n    }, {\n        key: 'setError',\n        value: function setError() {\n            this.props.dispatch({\n                type: 'set_errors',\n                errors: {\n                    email: 'Error message from remote'\n                }\n            });\n        }\n    }, {\n        key: 'setErrors',\n        value: function setErrors() {\n            this.props.dispatch({\n                type: 'set_errors',\n                errors: {\n                    email: 'A-Error message from remote',\n                    username: 'B-Error message from remote'\n                }\n            });\n        }\n    }, {\n        key: 'render',\n        value: function render() {\n            var _this2 = this;\n\n            return React.createElement(\n                _next.Form,\n                { field: this.field },\n                React.createElement(\n                    _next.Form.Item,\n                    { required: true, format: 'email' },\n                    React.createElement(_next.Input, { name: 'email' })\n                ),\n                React.createElement(\n                    _next.Form.Item,\n                    { help: '', required: true, requiredMessage: 'required' },\n                    React.createElement(_next.Input, { name: 'username', defaultValue: this.props.formData.values.username }),\n                    React.createElement(\n                        'p',\n                        { style: { color: 'blue' } },\n                        this.field.getError('username')\n                    )\n                ),\n                React.createElement(\n                    'p',\n                    null,\n                    'email: ',\n                    this.props.email && this.props.email.value\n                ),\n                React.createElement(\n                    _next.Button,\n                    { onClick: this.setEmail.bind(this) },\n                    'setEmail'\n                ),\n                React.createElement(\n                    _next.Button,\n                    { onClick: this.setName.bind(this) },\n                    'setName'\n                ),\n                React.createElement(\n                    _next.Button,\n                    { onClick: this.setError.bind(this) },\n                    'setError'\n                ),\n                React.createElement(\n                    _next.Button,\n                    { onClick: this.setErrors.bind(this) },\n                    'setErrors'\n                ),\n                React.createElement(\n                    _next.Button,\n                    { onClick: function onClick() {\n                            return _this2.field.reset();\n                        } },\n                    'reset'\n                )\n            );\n        }\n    }]);\n\n    return FormDemo;\n}(React.Component);\n\nvar ReduxFormDemo = (0, _reactRedux.connect)(function (state) {\n    return {\n        formData: state.formReducer\n    };\n})(FormDemo);\n\nvar store = (0, _redux.createStore)((0, _redux.combineReducers)({\n    formReducer: formReducer\n}));\n\nReactDOM.render(React.createElement(\n    _reactRedux.Provider,\n    { store: store },\n    React.createElement(\n        'div',\n        null,\n        React.createElement(ReduxFormDemo, null)\n    )\n), mountNode);})()</script><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> Form<span class=\"token punctuation\">,</span> Input<span class=\"token punctuation\">,</span> Button<span class=\"token punctuation\">,</span> Field <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next'</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> combineReducers<span class=\"token punctuation\">,</span> createStore <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'redux'</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> Provider<span class=\"token punctuation\">,</span> connect <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'react-redux'</span><span class=\"token punctuation\">;</span>\n\n\n\n<span class=\"token keyword\">const</span> initState <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n    values<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>email<span class=\"token operator\">:</span> <span class=\"token string\">''</span><span class=\"token punctuation\">,</span> username<span class=\"token operator\">:</span> <span class=\"token string\">'xiachi'</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    errors<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span><span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">function</span> <span class=\"token function\">formReducer</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">state <span class=\"token operator\">=</span> initState<span class=\"token punctuation\">,</span> action</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">switch</span> <span class=\"token punctuation\">(</span>action<span class=\"token punctuation\">.</span>type<span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">case</span> <span class=\"token string\">'save_fields'</span><span class=\"token operator\">:</span>\n            <span class=\"token keyword\">return</span> <span class=\"token punctuation\">{</span>\n                <span class=\"token operator\">...</span>state<span class=\"token punctuation\">,</span>\n                values<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n                    <span class=\"token operator\">...</span>state<span class=\"token punctuation\">.</span>values<span class=\"token punctuation\">,</span>\n                    <span class=\"token operator\">...</span>action<span class=\"token punctuation\">.</span>values\n                <span class=\"token punctuation\">}</span>\n            <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">case</span> <span class=\"token string\">'set_errors'</span><span class=\"token operator\">:</span>\n            <span class=\"token keyword\">return</span> <span class=\"token punctuation\">{</span>\n                <span class=\"token operator\">...</span>state<span class=\"token punctuation\">,</span>\n                errors<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n                    <span class=\"token operator\">...</span>state<span class=\"token punctuation\">.</span>errors<span class=\"token punctuation\">,</span>\n                    <span class=\"token operator\">...</span>action<span class=\"token punctuation\">.</span>errors\n                <span class=\"token punctuation\">}</span>\n            <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">default</span><span class=\"token operator\">:</span>\n            <span class=\"token keyword\">return</span> state<span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">FormDemo</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token function\">constructor</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">props</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">super</span><span class=\"token punctuation\">(</span>props<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>field <span class=\"token operator\">=</span> <span class=\"token keyword\">new</span> <span class=\"token class-name\">Field</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">,</span> <span class=\"token punctuation\">{</span>\n            <span class=\"token function-variable function\">onChange</span><span class=\"token operator\">:</span> <span class=\"token punctuation\">(</span><span class=\"token parameter\">name<span class=\"token punctuation\">,</span> value</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n                console<span class=\"token punctuation\">.</span><span class=\"token function\">log</span><span class=\"token punctuation\">(</span><span class=\"token string\">'onChange'</span><span class=\"token punctuation\">,</span> name<span class=\"token punctuation\">,</span> value<span class=\"token punctuation\">,</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>field<span class=\"token punctuation\">.</span><span class=\"token function\">getError</span><span class=\"token punctuation\">(</span>name<span class=\"token punctuation\">)</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n                <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">.</span><span class=\"token function\">dispatch</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n                    type<span class=\"token operator\">:</span> <span class=\"token string\">'save_fields'</span><span class=\"token punctuation\">,</span>\n                    values<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n                        <span class=\"token punctuation\">[</span>name<span class=\"token punctuation\">]</span><span class=\"token operator\">:</span> value\n                    <span class=\"token punctuation\">}</span>\n                <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n                <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">.</span><span class=\"token function\">dispatch</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n                    type<span class=\"token operator\">:</span> <span class=\"token string\">'set_errors'</span><span class=\"token punctuation\">,</span>\n                    errors<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n                        <span class=\"token punctuation\">[</span>name<span class=\"token punctuation\">]</span><span class=\"token operator\">:</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>field<span class=\"token punctuation\">.</span><span class=\"token function\">getError</span><span class=\"token punctuation\">(</span>name<span class=\"token punctuation\">)</span>\n                    <span class=\"token punctuation\">}</span>\n                <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n            <span class=\"token punctuation\">}</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">componentWillReceiveProps</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">nextProps</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>field<span class=\"token punctuation\">.</span><span class=\"token function\">setValues</span><span class=\"token punctuation\">(</span>nextProps<span class=\"token punctuation\">.</span>formData<span class=\"token punctuation\">.</span>values<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>field<span class=\"token punctuation\">.</span><span class=\"token function\">setErrors</span><span class=\"token punctuation\">(</span>nextProps<span class=\"token punctuation\">.</span>formData<span class=\"token punctuation\">.</span>errors<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">setEmail</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">.</span><span class=\"token function\">dispatch</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            type<span class=\"token operator\">:</span> <span class=\"token string\">'save_fields'</span><span class=\"token punctuation\">,</span>\n            values<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n                email<span class=\"token operator\">:</span> <span class=\"token string\">'qq@gmail.com'</span>\n            <span class=\"token punctuation\">}</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">setName</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">.</span><span class=\"token function\">dispatch</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            type<span class=\"token operator\">:</span> <span class=\"token string\">'save_fields'</span><span class=\"token punctuation\">,</span>\n            values<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n                username<span class=\"token operator\">:</span> <span class=\"token string\">'frank'</span>\n            <span class=\"token punctuation\">}</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">setError</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">.</span><span class=\"token function\">dispatch</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            type<span class=\"token operator\">:</span> <span class=\"token string\">'set_errors'</span><span class=\"token punctuation\">,</span>\n            errors<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n                email<span class=\"token operator\">:</span> <span class=\"token string\">'Error message from remote'</span>\n            <span class=\"token punctuation\">}</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">setErrors</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">.</span><span class=\"token function\">dispatch</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            type<span class=\"token operator\">:</span> <span class=\"token string\">'set_errors'</span><span class=\"token punctuation\">,</span>\n            errors<span class=\"token operator\">:</span> <span class=\"token punctuation\">{</span>\n                email<span class=\"token operator\">:</span> <span class=\"token string\">'A-Error message from remote'</span><span class=\"token punctuation\">,</span>\n                username<span class=\"token operator\">:</span> <span class=\"token string\">'B-Error message from remote'</span>\n            <span class=\"token punctuation\">}</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Form</span></span> <span class=\"token attr-name\">field</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>field<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Form.Item</span></span> <span class=\"token attr-name\">required</span> <span class=\"token attr-name\">format</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>email<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Input</span></span> <span class=\"token attr-name\">name</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>email<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Form.Item</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Form.Item</span></span> <span class=\"token attr-name\">help</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span><span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">required</span> <span class=\"token attr-name\">requiredMessage</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>required<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Input</span></span> <span class=\"token attr-name\">name</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>username<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">defaultValue</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">.</span>formData<span class=\"token punctuation\">.</span>values<span class=\"token punctuation\">.</span>username<span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>p</span> <span class=\"token attr-name\">style</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span>color<span class=\"token operator\">:</span> <span class=\"token string\">'blue'</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>field<span class=\"token punctuation\">.</span><span class=\"token function\">getError</span><span class=\"token punctuation\">(</span><span class=\"token string\">'username'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>p</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Form.Item</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>p</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">email: </span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">.</span>email <span class=\"token operator\">&amp;&amp;</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">.</span>email<span class=\"token punctuation\">.</span>value<span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>p</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setEmail</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">setEmail</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setName</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">setName</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setError</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">setError</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setErrors</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">setErrors</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>field<span class=\"token punctuation\">.</span><span class=\"token function\">reset</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">reset</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Form</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\n\n\n<span class=\"token keyword\">const</span> ReduxFormDemo <span class=\"token operator\">=</span> <span class=\"token function\">connect</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">state</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">return</span> <span class=\"token punctuation\">{</span>\n        formData<span class=\"token operator\">:</span> state<span class=\"token punctuation\">.</span>formReducer\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">(</span>FormDemo<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> store <span class=\"token operator\">=</span> <span class=\"token function\">createStore</span><span class=\"token punctuation\">(</span><span class=\"token function\">combineReducers</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n    formReducer\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\nReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Provider</span></span> <span class=\"token attr-name\">store</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>store<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">ReduxFormDemo</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Provider</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">,</span> mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div>"}