{"title":"受控模式","meta":{"title":"受控模式","description":"\n<p>默认情况下，Step 定义为展示型组件，上层组件可以通过修改传入的 current 属性值来修改当前的步骤，同时可以设置每个节点的 click 事件，来自定义回调。</p>\n","order":"6"},"codes":{"jsx":"import { Step, Button, Select, Icon } from '@alifd/next';\n\nconst StepItem = Step.Item, ButtonGroup = Button.Group;\n\nconst renders = {\n    1: function itemRender1(index) {\n        return <div className=\"custom-node1\"><span>{index + 1}</span></div>;\n    },\n    2: function itemRender2(index, status) {\n        return <div className=\"custom-node2\">{status === 'finish' ? <Icon type=\"success\" /> : <span>{index + 1}</span>} </div>;\n    }\n};\nconst contents = [\n  'Description1',\n  'Description2 --- Very Looooooooooooooooooooooog content',\n  'Description3'\n];\n\nclass Component extends React.Component {\n    constructor(props) {\n        super(props);\n\n        this.state = {\n            currentStep: 3,\n            stepType: 'circle',\n            stepAnimation: true,\n            labelPlacement: 'ver'\n        };\n\n        this.onClick = this.onClick.bind(this);\n    }\n    next() {\n        const s = this.state.currentStep + 1;\n\n        this.setState({\n            currentStep: s > 6 ? 6 : s\n        });\n    }\n    prev() {\n        const s = this.state.currentStep - 1;\n\n        this.setState({\n            currentStep: s < 0 ? 0 : s\n        });\n    }\n    onClick(currentStep) {\n        console.log(currentStep);\n\n        this.setState({\n            currentStep: currentStep\n        });\n    }\n    onStepTypeChange(value) {\n        this.setState({ stepType: value });\n    }\n    onStepAnimation(value) {\n        this.setState({ stepAnimation: value });\n    }\n    onLabelPlacementChange(value) {\n        this.setState({ labelPlacement: value });\n    }\n    onItemRenderChange(value) {\n        this.setState({ itemRender: renders[value], content: contents[value]});\n    }\n    render() {\n        const {currentStep} = this.state;\n\n        return (\n            <div>\n                <div className=\"custom-step-option\">\n                    <Select innerBefore=\"shape:\" placeholder=\"Choose the dispaly type\" onChange={this.onStepTypeChange.bind(this)} className=\"custom-select\" defaultValue=\"circle\">\n                        {\n                            ['circle', 'arrow', 'dot'].map(item => <Select.Option value={item} key={item}>{item}</Select.Option>)\n                        }\n                    </Select>\n\n                    <Select innerBefore=\"labelPlacement:\" placeholder=\"Label placement\" onChange={this.onLabelPlacementChange.bind(this)} className=\"custom-select\" defaultValue=\"hoz\">\n                        {\n                            ['hoz', 'ver'].map(item => <Select.Option value={item} key={item}>{item}</Select.Option>)\n                        }\n                    </Select>\n\n                    <Select innerBefore=\"animation:\" placeholder=\"Enable animation\" onChange={this.onStepAnimation.bind(this)} className=\"custom-select\" defaultValue>\n                        {\n                            [true, false].map((item, index) => <Select.Option value={item} key={index}>{item ? 'on' : 'off'}</Select.Option>)\n                        }\n                    </Select>\n\n                    <Select innerBefore=\"render:\" placeholder=\"Choose itemRender\" onChange={this.onItemRenderChange.bind(this)} className=\"custom-select\" defaultValue={0}>\n                        {\n                            ['ItemRender', 'ItemRender1', 'ItemRender2'].map((item, index) => <Select.Option value={index} key={index}>{item}</Select.Option>)\n                        }\n                    </Select>\n                </div>\n\n                <Step itemRender={this.state.itemRender} current={currentStep} shape={this.state.stepType} animation={this.state.stepAnimation} labelPlacement={this.state.labelPlacement}>\n                    <StepItem title=\"Step 1\" onClick={this.onClick} content=\"Description\" />\n                    <StepItem title=\"Step 2\" onClick={this.onClick} content=\"Description\" />\n                    <StepItem title=\"Step 3\" onClick={this.onClick} content={this.state.content || 'Description1'} />\n                    <StepItem title=\"Step 4\" onClick={this.onClick} content=\"Description\" />\n                    <StepItem title=\"Step 5\" onClick={this.onClick} content=\"Description\" />\n                    <StepItem title=\"Step 6\" onClick={this.onClick} content=\"Description\" />\n                </Step>\n                <br />\n                <br />\n                <ButtonGroup>\n                    <Button onClick={this.prev.bind(this)} type=\"primary\" disabled={currentStep === 0}>Backward</Button>\n                    <Button onClick={this.next.bind(this)} type=\"primary\" disabled={currentStep === 6}>Forward</Button>\n                </ButtonGroup>\n            </div>\n        );\n    }\n}\n\nReactDOM.render(<Component />, mountNode);\n","css":".custom-step-option {\n    margin-bottom: 20px;\n}\n\n.custom-select {\n    margin-right: 20px;\n}\n.next-input-inner.next-before {\n    margin-left: 8px;\n}.fusion-demo-item {\n     margin: 15px 0;\n }\n .custom-node1 {\n     height: 100%;\n     width: 100%;\n     border-radius: 20%;\n     border: 1px dashed #3E71F1;\n     text-align: center;\n }\n .custom-node1 span {\n     font-size: 12px;\n \n     position: absolute;\n     top: 50%;\n     text-align: center;\n     width: 100%;\n     left: 0;\n     transform: translateY(-50%);\n }\n .custom-node2 {\n     height: 100%;\n     width: 100%;\n     border-radius: 20%;\n     border: 1px dashed #3E71F1;\n     text-align: center;\n     background: #3E71F1;\n     color: #fff;\n     position: relative;\n }\n \n .custom-node2 span, .custom-node2 i {\n     position: absolute;\n     top: 50%;\n     transform: translateY(-50%);\n     left: 0;\n     width: 100%;\n     text-align: center;\n }\n\n"},"body":"\n\n\n````jsx\nimport { Step, Button, Select, Icon } from '@alifd/next';\n\nconst StepItem = Step.Item, ButtonGroup = Button.Group;\n\nconst renders = {\n    1: function itemRender1(index) {\n        return <div className=\"custom-node1\"><span>{index + 1}</span></div>;\n    },\n    2: function itemRender2(index, status) {\n        return <div className=\"custom-node2\">{status === 'finish' ? <Icon type=\"success\" /> : <span>{index + 1}</span>} </div>;\n    }\n};\nconst contents = [\n  'Description1',\n  'Description2 --- Very Looooooooooooooooooooooog content',\n  'Description3'\n];\n\nclass Component extends React.Component {\n    constructor(props) {\n        super(props);\n\n        this.state = {\n            currentStep: 3,\n            stepType: 'circle',\n            stepAnimation: true,\n            labelPlacement: 'ver'\n        };\n\n        this.onClick = this.onClick.bind(this);\n    }\n    next() {\n        const s = this.state.currentStep + 1;\n\n        this.setState({\n            currentStep: s > 6 ? 6 : s\n        });\n    }\n    prev() {\n        const s = this.state.currentStep - 1;\n\n        this.setState({\n            currentStep: s < 0 ? 0 : s\n        });\n    }\n    onClick(currentStep) {\n        console.log(currentStep);\n\n        this.setState({\n            currentStep: currentStep\n        });\n    }\n    onStepTypeChange(value) {\n        this.setState({ stepType: value });\n    }\n    onStepAnimation(value) {\n        this.setState({ stepAnimation: value });\n    }\n    onLabelPlacementChange(value) {\n        this.setState({ labelPlacement: value });\n    }\n    onItemRenderChange(value) {\n        this.setState({ itemRender: renders[value], content: contents[value]});\n    }\n    render() {\n        const {currentStep} = this.state;\n\n        return (\n            <div>\n                <div className=\"custom-step-option\">\n                    <Select innerBefore=\"shape:\" placeholder=\"Choose the dispaly type\" onChange={this.onStepTypeChange.bind(this)} className=\"custom-select\" defaultValue=\"circle\">\n                        {\n                            ['circle', 'arrow', 'dot'].map(item => <Select.Option value={item} key={item}>{item}</Select.Option>)\n                        }\n                    </Select>\n\n                    <Select innerBefore=\"labelPlacement:\" placeholder=\"Label placement\" onChange={this.onLabelPlacementChange.bind(this)} className=\"custom-select\" defaultValue=\"hoz\">\n                        {\n                            ['hoz', 'ver'].map(item => <Select.Option value={item} key={item}>{item}</Select.Option>)\n                        }\n                    </Select>\n\n                    <Select innerBefore=\"animation:\" placeholder=\"Enable animation\" onChange={this.onStepAnimation.bind(this)} className=\"custom-select\" defaultValue>\n                        {\n                            [true, false].map((item, index) => <Select.Option value={item} key={index}>{item ? 'on' : 'off'}</Select.Option>)\n                        }\n                    </Select>\n\n                    <Select innerBefore=\"render:\" placeholder=\"Choose itemRender\" onChange={this.onItemRenderChange.bind(this)} className=\"custom-select\" defaultValue={0}>\n                        {\n                            ['ItemRender', 'ItemRender1', 'ItemRender2'].map((item, index) => <Select.Option value={index} key={index}>{item}</Select.Option>)\n                        }\n                    </Select>\n                </div>\n\n                <Step itemRender={this.state.itemRender} current={currentStep} shape={this.state.stepType} animation={this.state.stepAnimation} labelPlacement={this.state.labelPlacement}>\n                    <StepItem title=\"Step 1\" onClick={this.onClick} content=\"Description\" />\n                    <StepItem title=\"Step 2\" onClick={this.onClick} content=\"Description\" />\n                    <StepItem title=\"Step 3\" onClick={this.onClick} content={this.state.content || 'Description1'} />\n                    <StepItem title=\"Step 4\" onClick={this.onClick} content=\"Description\" />\n                    <StepItem title=\"Step 5\" onClick={this.onClick} content=\"Description\" />\n                    <StepItem title=\"Step 6\" onClick={this.onClick} content=\"Description\" />\n                </Step>\n                <br />\n                <br />\n                <ButtonGroup>\n                    <Button onClick={this.prev.bind(this)} type=\"primary\" disabled={currentStep === 0}>Backward</Button>\n                    <Button onClick={this.next.bind(this)} type=\"primary\" disabled={currentStep === 6}>Forward</Button>\n                </ButtonGroup>\n            </div>\n        );\n    }\n}\n\nReactDOM.render(<Component />, mountNode);\n````\n\n````css\n.custom-step-option {\n    margin-bottom: 20px;\n}\n\n.custom-select {\n    margin-right: 20px;\n}\n.next-input-inner.next-before {\n    margin-left: 8px;\n}.fusion-demo-item {\n     margin: 15px 0;\n }\n .custom-node1 {\n     height: 100%;\n     width: 100%;\n     border-radius: 20%;\n     border: 1px dashed #3E71F1;\n     text-align: center;\n }\n .custom-node1 span {\n     font-size: 12px;\n \n     position: absolute;\n     top: 50%;\n     text-align: center;\n     width: 100%;\n     left: 0;\n     transform: translateY(-50%);\n }\n .custom-node2 {\n     height: 100%;\n     width: 100%;\n     border-radius: 20%;\n     border: 1px dashed #3E71F1;\n     text-align: center;\n     background: #3E71F1;\n     color: #fff;\n     position: relative;\n }\n \n .custom-node2 span, .custom-node2 i {\n     position: absolute;\n     top: 50%;\n     transform: translateY(-50%);\n     left: 0;\n     width: 100%;\n     text-align: center;\n }\n\n````","html":"<script>(function(){\"use strict\";\n\nvar _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();\n\nvar _next = require(\"@alifd/next\");\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return call && (typeof call === \"object\" || typeof call === \"function\") ? call : self; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function, not \" + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }\n\nvar StepItem = _next.Step.Item,\n    ButtonGroup = _next.Button.Group;\n\nvar renders = {\n    1: function itemRender1(index) {\n        return React.createElement(\n            \"div\",\n            { className: \"custom-node1\" },\n            React.createElement(\n                \"span\",\n                null,\n                index + 1\n            )\n        );\n    },\n    2: function itemRender2(index, status) {\n        return React.createElement(\n            \"div\",\n            { className: \"custom-node2\" },\n            status === 'finish' ? React.createElement(_next.Icon, { type: \"success\" }) : React.createElement(\n                \"span\",\n                null,\n                index + 1\n            ),\n            \" \"\n        );\n    }\n};\nvar contents = ['Description1', 'Description2 --- Very Looooooooooooooooooooooog content', 'Description3'];\n\nvar Component = function (_React$Component) {\n    _inherits(Component, _React$Component);\n\n    function Component(props) {\n        _classCallCheck(this, Component);\n\n        var _this = _possibleConstructorReturn(this, (Component.__proto__ || Object.getPrototypeOf(Component)).call(this, props));\n\n        _this.state = {\n            currentStep: 3,\n            stepType: 'circle',\n            stepAnimation: true,\n            labelPlacement: 'ver'\n        };\n\n        _this.onClick = _this.onClick.bind(_this);\n        return _this;\n    }\n\n    _createClass(Component, [{\n        key: \"next\",\n        value: function next() {\n            var s = this.state.currentStep + 1;\n\n            this.setState({\n                currentStep: s > 6 ? 6 : s\n            });\n        }\n    }, {\n        key: \"prev\",\n        value: function prev() {\n            var s = this.state.currentStep - 1;\n\n            this.setState({\n                currentStep: s < 0 ? 0 : s\n            });\n        }\n    }, {\n        key: \"onClick\",\n        value: function onClick(currentStep) {\n            console.log(currentStep);\n\n            this.setState({\n                currentStep: currentStep\n            });\n        }\n    }, {\n        key: \"onStepTypeChange\",\n        value: function onStepTypeChange(value) {\n            this.setState({ stepType: value });\n        }\n    }, {\n        key: \"onStepAnimation\",\n        value: function onStepAnimation(value) {\n            this.setState({ stepAnimation: value });\n        }\n    }, {\n        key: \"onLabelPlacementChange\",\n        value: function onLabelPlacementChange(value) {\n            this.setState({ labelPlacement: value });\n        }\n    }, {\n        key: \"onItemRenderChange\",\n        value: function onItemRenderChange(value) {\n            this.setState({ itemRender: renders[value], content: contents[value] });\n        }\n    }, {\n        key: \"render\",\n        value: function render() {\n            var currentStep = this.state.currentStep;\n\n\n            return React.createElement(\n                \"div\",\n                null,\n                React.createElement(\n                    \"div\",\n                    { className: \"custom-step-option\" },\n                    React.createElement(\n                        _next.Select,\n                        { innerBefore: \"shape:\", placeholder: \"Choose the dispaly type\", onChange: this.onStepTypeChange.bind(this), className: \"custom-select\", defaultValue: \"circle\" },\n                        ['circle', 'arrow', 'dot'].map(function (item) {\n                            return React.createElement(\n                                _next.Select.Option,\n                                { value: item, key: item },\n                                item\n                            );\n                        })\n                    ),\n                    React.createElement(\n                        _next.Select,\n                        { innerBefore: \"labelPlacement:\", placeholder: \"Label placement\", onChange: this.onLabelPlacementChange.bind(this), className: \"custom-select\", defaultValue: \"hoz\" },\n                        ['hoz', 'ver'].map(function (item) {\n                            return React.createElement(\n                                _next.Select.Option,\n                                { value: item, key: item },\n                                item\n                            );\n                        })\n                    ),\n                    React.createElement(\n                        _next.Select,\n                        { innerBefore: \"animation:\", placeholder: \"Enable animation\", onChange: this.onStepAnimation.bind(this), className: \"custom-select\", defaultValue: true },\n                        [true, false].map(function (item, index) {\n                            return React.createElement(\n                                _next.Select.Option,\n                                { value: item, key: index },\n                                item ? 'on' : 'off'\n                            );\n                        })\n                    ),\n                    React.createElement(\n                        _next.Select,\n                        { innerBefore: \"render:\", placeholder: \"Choose itemRender\", onChange: this.onItemRenderChange.bind(this), className: \"custom-select\", defaultValue: 0 },\n                        ['ItemRender', 'ItemRender1', 'ItemRender2'].map(function (item, index) {\n                            return React.createElement(\n                                _next.Select.Option,\n                                { value: index, key: index },\n                                item\n                            );\n                        })\n                    )\n                ),\n                React.createElement(\n                    _next.Step,\n                    { itemRender: this.state.itemRender, current: currentStep, shape: this.state.stepType, animation: this.state.stepAnimation, labelPlacement: this.state.labelPlacement },\n                    React.createElement(StepItem, { title: \"Step 1\", onClick: this.onClick, content: \"Description\" }),\n                    React.createElement(StepItem, { title: \"Step 2\", onClick: this.onClick, content: \"Description\" }),\n                    React.createElement(StepItem, { title: \"Step 3\", onClick: this.onClick, content: this.state.content || 'Description1' }),\n                    React.createElement(StepItem, { title: \"Step 4\", onClick: this.onClick, content: \"Description\" }),\n                    React.createElement(StepItem, { title: \"Step 5\", onClick: this.onClick, content: \"Description\" }),\n                    React.createElement(StepItem, { title: \"Step 6\", onClick: this.onClick, content: \"Description\" })\n                ),\n                React.createElement(\"br\", null),\n                React.createElement(\"br\", null),\n                React.createElement(\n                    ButtonGroup,\n                    null,\n                    React.createElement(\n                        _next.Button,\n                        { onClick: this.prev.bind(this), type: \"primary\", disabled: currentStep === 0 },\n                        \"Backward\"\n                    ),\n                    React.createElement(\n                        _next.Button,\n                        { onClick: this.next.bind(this), type: \"primary\", disabled: currentStep === 6 },\n                        \"Forward\"\n                    )\n                )\n            );\n        }\n    }]);\n\n    return Component;\n}(React.Component);\n\nReactDOM.render(React.createElement(Component, null), mountNode);})()</script><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> Step<span class=\"token punctuation\">,</span> Button<span class=\"token punctuation\">,</span> Select<span class=\"token punctuation\">,</span> Icon <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next'</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> StepItem <span class=\"token operator\">=</span> Step<span class=\"token punctuation\">.</span>Item<span class=\"token punctuation\">,</span> ButtonGroup <span class=\"token operator\">=</span> Button<span class=\"token punctuation\">.</span>Group<span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> renders <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token number\">1</span><span class=\"token operator\">:</span> <span class=\"token keyword\">function</span> <span class=\"token function\">itemRender1</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">index</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>custom-node1<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>span</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>index <span class=\"token operator\">+</span> <span class=\"token number\">1</span><span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>span</span><span class=\"token punctuation\">></span></span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    <span class=\"token number\">2</span><span class=\"token operator\">:</span> <span class=\"token keyword\">function</span> <span class=\"token function\">itemRender2</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">index<span class=\"token punctuation\">,</span> status</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>custom-node2<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>status <span class=\"token operator\">===</span> <span class=\"token string\">'finish'</span> <span class=\"token operator\">?</span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Icon</span></span> <span class=\"token attr-name\">type</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>success<span class=\"token punctuation\">\"</span></span> <span class=\"token punctuation\">/></span></span> <span class=\"token operator\">:</span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>span</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>index <span class=\"token operator\">+</span> <span class=\"token number\">1</span><span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>span</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">}</span><span class=\"token plain-text\"> </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">const</span> contents <span class=\"token operator\">=</span> <span class=\"token punctuation\">[</span>\n  <span class=\"token string\">'Description1'</span><span class=\"token punctuation\">,</span>\n  <span class=\"token string\">'Description2 --- Very Looooooooooooooooooooooog content'</span><span class=\"token punctuation\">,</span>\n  <span class=\"token string\">'Description3'</span>\n<span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">Component</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token function\">constructor</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">props</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">super</span><span class=\"token punctuation\">(</span>props<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n            currentStep<span class=\"token operator\">:</span> <span class=\"token number\">3</span><span class=\"token punctuation\">,</span>\n            stepType<span class=\"token operator\">:</span> <span class=\"token string\">'circle'</span><span class=\"token punctuation\">,</span>\n            stepAnimation<span class=\"token operator\">:</span> <span class=\"token boolean\">true</span><span class=\"token punctuation\">,</span>\n            labelPlacement<span class=\"token operator\">:</span> <span class=\"token string\">'ver'</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>onClick <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">onClick</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n    <span class=\"token function\">next</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">const</span> s <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>currentStep <span class=\"token operator\">+</span> <span class=\"token number\">1</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setState</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            currentStep<span class=\"token operator\">:</span> s <span class=\"token operator\">></span> <span class=\"token number\">6</span> <span class=\"token operator\">?</span> <span class=\"token number\">6</span> <span class=\"token operator\">:</span> s\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n    <span class=\"token function\">prev</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">const</span> s <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>currentStep <span class=\"token operator\">-</span> <span class=\"token number\">1</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setState</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            currentStep<span class=\"token operator\">:</span> s <span class=\"token operator\">&lt;</span> <span class=\"token number\">0</span> <span class=\"token operator\">?</span> <span class=\"token number\">0</span> <span class=\"token operator\">:</span> s\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n    <span class=\"token function\">onClick</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">currentStep</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        console<span class=\"token punctuation\">.</span><span class=\"token function\">log</span><span class=\"token punctuation\">(</span>currentStep<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setState</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            currentStep<span class=\"token operator\">:</span> currentStep\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n    <span class=\"token function\">onStepTypeChange</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">value</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setState</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span> stepType<span class=\"token operator\">:</span> value <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n    <span class=\"token function\">onStepAnimation</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">value</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setState</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span> stepAnimation<span class=\"token operator\">:</span> value <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n    <span class=\"token function\">onLabelPlacementChange</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">value</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setState</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span> labelPlacement<span class=\"token operator\">:</span> value <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n    <span class=\"token function\">onItemRenderChange</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">value</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setState</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span> itemRender<span class=\"token operator\">:</span> renders<span class=\"token punctuation\">[</span>value<span class=\"token punctuation\">]</span><span class=\"token punctuation\">,</span> content<span class=\"token operator\">:</span> contents<span class=\"token punctuation\">[</span>value<span class=\"token punctuation\">]</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span>currentStep<span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span>\n            <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>custom-step-option<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select</span></span> <span class=\"token attr-name\">innerBefore</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>shape:<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">placeholder</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Choose the dispaly type<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onChange</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">onStepTypeChange</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>custom-select<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">defaultValue</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>circle<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token punctuation\">{</span>\n                            <span class=\"token punctuation\">[</span><span class=\"token string\">'circle'</span><span class=\"token punctuation\">,</span> <span class=\"token string\">'arrow'</span><span class=\"token punctuation\">,</span> <span class=\"token string\">'dot'</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">.</span><span class=\"token function\">map</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">item</span> <span class=\"token operator\">=></span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select.Option</span></span> <span class=\"token attr-name\">value</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">key</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Select.Option</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span>\n                        <span class=\"token punctuation\">}</span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Select</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select</span></span> <span class=\"token attr-name\">innerBefore</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>labelPlacement:<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">placeholder</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Label placement<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onChange</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">onLabelPlacementChange</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>custom-select<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">defaultValue</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>hoz<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token punctuation\">{</span>\n                            <span class=\"token punctuation\">[</span><span class=\"token string\">'hoz'</span><span class=\"token punctuation\">,</span> <span class=\"token string\">'ver'</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">.</span><span class=\"token function\">map</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">item</span> <span class=\"token operator\">=></span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select.Option</span></span> <span class=\"token attr-name\">value</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">key</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Select.Option</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span>\n                        <span class=\"token punctuation\">}</span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Select</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select</span></span> <span class=\"token attr-name\">innerBefore</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>animation:<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">placeholder</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Enable animation<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onChange</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">onStepAnimation</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>custom-select<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">defaultValue</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token punctuation\">{</span>\n                            <span class=\"token punctuation\">[</span><span class=\"token boolean\">true</span><span class=\"token punctuation\">,</span> <span class=\"token boolean\">false</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">.</span><span class=\"token function\">map</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">item<span class=\"token punctuation\">,</span> index</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select.Option</span></span> <span class=\"token attr-name\">value</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">key</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>index<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>item <span class=\"token operator\">?</span> <span class=\"token string\">'on'</span> <span class=\"token operator\">:</span> <span class=\"token string\">'off'</span><span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Select.Option</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span>\n                        <span class=\"token punctuation\">}</span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Select</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select</span></span> <span class=\"token attr-name\">innerBefore</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>render:<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">placeholder</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Choose itemRender<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onChange</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">onItemRenderChange</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>custom-select<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">defaultValue</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token number\">0</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token punctuation\">{</span>\n                            <span class=\"token punctuation\">[</span><span class=\"token string\">'ItemRender'</span><span class=\"token punctuation\">,</span> <span class=\"token string\">'ItemRender1'</span><span class=\"token punctuation\">,</span> <span class=\"token string\">'ItemRender2'</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">.</span><span class=\"token function\">map</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">item<span class=\"token punctuation\">,</span> index</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select.Option</span></span> <span class=\"token attr-name\">value</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>index<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">key</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>index<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Select.Option</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span>\n                        <span class=\"token punctuation\">}</span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Select</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Step</span></span> <span class=\"token attr-name\">itemRender</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>itemRender<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">current</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>currentStep<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">shape</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>stepType<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">animation</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>stepAnimation<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">labelPlacement</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>labelPlacement<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">StepItem</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Step 1<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>onClick<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">content</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Description<span class=\"token punctuation\">\"</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">StepItem</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Step 2<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>onClick<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">content</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Description<span class=\"token punctuation\">\"</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">StepItem</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Step 3<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>onClick<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">content</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>content <span class=\"token operator\">||</span> <span class=\"token string\">'Description1'</span><span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">StepItem</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Step 4<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>onClick<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">content</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Description<span class=\"token punctuation\">\"</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">StepItem</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Step 5<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>onClick<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">content</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Description<span class=\"token punctuation\">\"</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">StepItem</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Step 6<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>onClick<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">content</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>Description<span class=\"token punctuation\">\"</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Step</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>br</span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>br</span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">ButtonGroup</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">prev</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">type</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>primary<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">disabled</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>currentStep <span class=\"token operator\">===</span> <span class=\"token number\">0</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Backward</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">next</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">type</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>primary<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">disabled</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>currentStep <span class=\"token operator\">===</span> <span class=\"token number\">6</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Forward</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">ButtonGroup</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span>\n        <span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\n\nReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Component</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token punctuation\">,</span> mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><style type=\"text/css\">.custom-step-option {\n    margin-bottom: 20px;\n}\n\n.custom-select {\n    margin-right: 20px;\n}\n.next-input-inner.next-before {\n    margin-left: 8px;\n}.fusion-demo-item {\n     margin: 15px 0;\n }\n .custom-node1 {\n     height: 100%;\n     width: 100%;\n     border-radius: 20%;\n     border: 1px dashed #3E71F1;\n     text-align: center;\n }\n .custom-node1 span {\n     font-size: 12px;\n\n     position: absolute;\n     top: 50%;\n     text-align: center;\n     width: 100%;\n     left: 0;\n     transform: translateY(-50%);\n }\n .custom-node2 {\n     height: 100%;\n     width: 100%;\n     border-radius: 20%;\n     border: 1px dashed #3E71F1;\n     text-align: center;\n     background: #3E71F1;\n     color: #fff;\n     position: relative;\n }\n\n .custom-node2 span, .custom-node2 i {\n     position: absolute;\n     top: 50%;\n     transform: translateY(-50%);\n     left: 0;\n     width: 100%;\n     text-align: center;\n }\n</style><div class=\"highlight\"><pre class=\"language-css\"><code class=\"language-css\"><span class=\"token selector\">.custom-step-option</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">margin-bottom</span><span class=\"token punctuation\">:</span> 20px<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token selector\">.custom-select</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">margin-right</span><span class=\"token punctuation\">:</span> 20px<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n<span class=\"token selector\">.next-input-inner.next-before</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">margin-left</span><span class=\"token punctuation\">:</span> 8px<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span><span class=\"token selector\">.fusion-demo-item</span> <span class=\"token punctuation\">{</span>\n     <span class=\"token property\">margin</span><span class=\"token punctuation\">:</span> 15px 0<span class=\"token punctuation\">;</span>\n <span class=\"token punctuation\">}</span>\n <span class=\"token selector\">.custom-node1</span> <span class=\"token punctuation\">{</span>\n     <span class=\"token property\">height</span><span class=\"token punctuation\">:</span> 100%<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">width</span><span class=\"token punctuation\">:</span> 100%<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">border-radius</span><span class=\"token punctuation\">:</span> 20%<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">border</span><span class=\"token punctuation\">:</span> 1px dashed #3E71F1<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">text-align</span><span class=\"token punctuation\">:</span> center<span class=\"token punctuation\">;</span>\n <span class=\"token punctuation\">}</span>\n <span class=\"token selector\">.custom-node1 span</span> <span class=\"token punctuation\">{</span>\n     <span class=\"token property\">font-size</span><span class=\"token punctuation\">:</span> 12px<span class=\"token punctuation\">;</span>\n\n     <span class=\"token property\">position</span><span class=\"token punctuation\">:</span> absolute<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">top</span><span class=\"token punctuation\">:</span> 50%<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">text-align</span><span class=\"token punctuation\">:</span> center<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">width</span><span class=\"token punctuation\">:</span> 100%<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">left</span><span class=\"token punctuation\">:</span> 0<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">transform</span><span class=\"token punctuation\">:</span> <span class=\"token function\">translateY</span><span class=\"token punctuation\">(</span>-50%<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n <span class=\"token punctuation\">}</span>\n <span class=\"token selector\">.custom-node2</span> <span class=\"token punctuation\">{</span>\n     <span class=\"token property\">height</span><span class=\"token punctuation\">:</span> 100%<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">width</span><span class=\"token punctuation\">:</span> 100%<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">border-radius</span><span class=\"token punctuation\">:</span> 20%<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">border</span><span class=\"token punctuation\">:</span> 1px dashed #3E71F1<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">text-align</span><span class=\"token punctuation\">:</span> center<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">background</span><span class=\"token punctuation\">:</span> #3E71F1<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">color</span><span class=\"token punctuation\">:</span> #fff<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">position</span><span class=\"token punctuation\">:</span> relative<span class=\"token punctuation\">;</span>\n <span class=\"token punctuation\">}</span>\n\n <span class=\"token selector\">.custom-node2 span, .custom-node2 i</span> <span class=\"token punctuation\">{</span>\n     <span class=\"token property\">position</span><span class=\"token punctuation\">:</span> absolute<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">top</span><span class=\"token punctuation\">:</span> 50%<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">transform</span><span class=\"token punctuation\">:</span> <span class=\"token function\">translateY</span><span class=\"token punctuation\">(</span>-50%<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n     <span class=\"token property\">left</span><span class=\"token punctuation\">:</span> 0<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">width</span><span class=\"token punctuation\">:</span> 100%<span class=\"token punctuation\">;</span>\n     <span class=\"token property\">text-align</span><span class=\"token punctuation\">:</span> center<span class=\"token punctuation\">;</span>\n <span class=\"token punctuation\">}</span>\n</code></pre></div>"}