{"title":"Custom tab","meta":{"title":"Custom tab","description":"\n<p>By default, tabs are rendered by a default template function. Howerver, you can pass your template function to <code>tabRender</code>.</p>\n","order":"10"},"codes":{"jsx":"import { Tab } from '@alifd/next';\n\nfunction CustomTabItem({ title, desc }) {\n    return (<div className=\"custom-tab-item\">\n        <div className=\"tab-title\">{title}</div>\n        <div className=\"tab-desc\">{desc}</div>\n    </div>);\n}\n\nconst panes = [\n    { key: 'e-checking', title: 'Alipay', desc: 'The fee to be paid is $15' },\n    { key: 'brand-card', title: 'Bank Card', desc: 'The fee to be paid is $17' }\n];\n\nReactDOM.render(\n    <Tab shape=\"wrapped\" tabRender={(key, props) => <CustomTabItem key={key} {...props} />}>\n        {\n            panes.map(pane => <Tab.Item key={pane.key} {...pane} tabStyle={{ height: '60px' }}>{pane.desc}</Tab.Item>)\n        }\n    </Tab>\n    , mountNode);\n","css":".custom-tab-item {\n    padding: 10px;\n}\n\n.tab-title {\n    font-size: 20px;\n}\n.tab-desc {\n    margin: 10px 0 0 0;\n    font-size: 12px;\n}\n.next-tabs-content {\n    color: #333;\n    font-size: 12px;\n    padding: 12px;\n}\n"},"body":"\n````jsx\nimport { Tab } from '@alifd/next';\n\nfunction CustomTabItem({ title, desc }) {\n    return (<div className=\"custom-tab-item\">\n        <div className=\"tab-title\">{title}</div>\n        <div className=\"tab-desc\">{desc}</div>\n    </div>);\n}\n\nconst panes = [\n    { key: 'e-checking', title: 'Alipay', desc: 'The fee to be paid is $15' },\n    { key: 'brand-card', title: 'Bank Card', desc: 'The fee to be paid is $17' }\n];\n\nReactDOM.render(\n    <Tab shape=\"wrapped\" tabRender={(key, props) => <CustomTabItem key={key} {...props} />}>\n        {\n            panes.map(pane => <Tab.Item key={pane.key} {...pane} tabStyle={{ height: '60px' }}>{pane.desc}</Tab.Item>)\n        }\n    </Tab>\n    , mountNode);\n````\n\n````css\n.custom-tab-item {\n    padding: 10px;\n}\n\n.tab-title {\n    font-size: 20px;\n}\n.tab-desc {\n    margin: 10px 0 0 0;\n    font-size: 12px;\n}\n.next-tabs-content {\n    color: #333;\n    font-size: 12px;\n    padding: 12px;\n}\n````","html":"<script>(function(){\"use strict\";\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nvar _next = require(\"@alifd/next\");\n\nfunction CustomTabItem(_ref) {\n    var title = _ref.title,\n        desc = _ref.desc;\n\n    return React.createElement(\n        \"div\",\n        { className: \"custom-tab-item\" },\n        React.createElement(\n            \"div\",\n            { className: \"tab-title\" },\n            title\n        ),\n        React.createElement(\n            \"div\",\n            { className: \"tab-desc\" },\n            desc\n        )\n    );\n}\n\nvar panes = [{ key: 'e-checking', title: 'Alipay', desc: 'The fee to be paid is $15' }, { key: 'brand-card', title: 'Bank Card', desc: 'The fee to be paid is $17' }];\n\nReactDOM.render(React.createElement(\n    _next.Tab,\n    { shape: \"wrapped\", tabRender: function tabRender(key, props) {\n            return React.createElement(CustomTabItem, _extends({ key: key }, props));\n        } },\n    panes.map(function (pane) {\n        return React.createElement(\n            _next.Tab.Item,\n            _extends({ key: pane.key }, pane, { tabStyle: { height: '60px' } }),\n            pane.desc\n        );\n    })\n), mountNode);})()</script><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> Tab <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next'</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">function</span> <span class=\"token function\">CustomTabItem</span><span class=\"token punctuation\">(</span><span class=\"token parameter\"><span class=\"token punctuation\">{</span> title<span class=\"token punctuation\">,</span> desc <span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>custom-tab-item<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>tab-title<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>title<span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>tab-desc<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>desc<span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token keyword\">const</span> panes <span class=\"token operator\">=</span> <span class=\"token punctuation\">[</span>\n    <span class=\"token punctuation\">{</span> key<span class=\"token operator\">:</span> <span class=\"token string\">'e-checking'</span><span class=\"token punctuation\">,</span> title<span class=\"token operator\">:</span> <span class=\"token string\">'Alipay'</span><span class=\"token punctuation\">,</span> desc<span class=\"token operator\">:</span> <span class=\"token string\">'The fee to be paid is $15'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    <span class=\"token punctuation\">{</span> key<span class=\"token operator\">:</span> <span class=\"token string\">'brand-card'</span><span class=\"token punctuation\">,</span> title<span class=\"token operator\">:</span> <span class=\"token string\">'Bank Card'</span><span class=\"token punctuation\">,</span> desc<span class=\"token operator\">:</span> <span class=\"token string\">'The fee to be paid is $17'</span> <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n\nReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span>\n    <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Tab</span></span> <span class=\"token attr-name\">shape</span><span class=\"token attr-value\"><span class=\"token punctuation attr-equals\">=</span><span class=\"token punctuation\">\"</span>wrapped<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">tabRender</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">key<span class=\"token punctuation\">,</span> props</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">CustomTabItem</span></span> <span class=\"token attr-name\">key</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>key<span class=\"token punctuation\">}</span></span> <span class=\"token spread\"><span class=\"token punctuation\">{</span><span class=\"token punctuation\">...</span><span class=\"token attr-value\">props</span><span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token punctuation\">{</span>\n            panes<span class=\"token punctuation\">.</span><span class=\"token function\">map</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">pane</span> <span class=\"token operator\">=></span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Tab.Item</span></span> <span class=\"token attr-name\">key</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>pane<span class=\"token punctuation\">.</span>key<span class=\"token punctuation\">}</span></span> <span class=\"token spread\"><span class=\"token punctuation\">{</span><span class=\"token punctuation\">...</span><span class=\"token attr-value\">pane</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">tabStyle</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span> height<span class=\"token operator\">:</span> <span class=\"token string\">'60px'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>pane<span class=\"token punctuation\">.</span>desc<span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Tab.Item</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span>\n        <span class=\"token punctuation\">}</span><span class=\"token plain-text\">\n    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Tab</span></span><span class=\"token punctuation\">></span></span>\n    <span class=\"token punctuation\">,</span> mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><style type=\"text/css\">.custom-tab-item {\n    padding: 10px;\n}\n\n.tab-title {\n    font-size: 20px;\n}\n.tab-desc {\n    margin: 10px 0 0 0;\n    font-size: 12px;\n}\n.next-tabs-content {\n    color: #333;\n    font-size: 12px;\n    padding: 12px;\n}</style><div class=\"highlight\"><pre class=\"language-css\"><code class=\"language-css\"><span class=\"token selector\">.custom-tab-item</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">padding</span><span class=\"token punctuation\">:</span> 10px<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token selector\">.tab-title</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">font-size</span><span class=\"token punctuation\">:</span> 20px<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n<span class=\"token selector\">.tab-desc</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">margin</span><span class=\"token punctuation\">:</span> 10px 0 0 0<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">font-size</span><span class=\"token punctuation\">:</span> 12px<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n<span class=\"token selector\">.next-tabs-content</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">color</span><span class=\"token punctuation\">:</span> #333<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">font-size</span><span class=\"token punctuation\">:</span> 12px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">padding</span><span class=\"token punctuation\">:</span> 12px<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span></code></pre></div>"}