{"title":"LazyLoad and AutoUnmount","meta":{"title":"LazyLoad and AutoUnmount","description":"\n<p>Disable lazy load by setting <code>lazyLoad={false}</code>, and enable auto unmount inactive tabs by setting <code>unmountInactiveTabs</code>.</p>\n","order":"3"},"codes":{"jsx":"import { Tab } from '@alifd/next';\n\nconst tabs = [\n    { tab: 'Home', key: 0, content: 'This is home page' },\n    { tab: 'Document', key: 1, content: 'This is document page' },\n    { tab: 'API', key: 2, content: 'This is api page' }\n];\n\nReactDOM.render(\n    <div>\n        <div>Render all tab contents</div>\n        <Tab lazyLoad={false}>\n            {\n                tabs.map(item => <Tab.Item key={item.key} title={item.tab}>{item.content}</Tab.Item>)\n            }\n        </Tab>\n\n        <div>Unmount inactive tabs</div>\n        <Tab unmountInactiveTabs>\n            {\n                tabs.map(item => <Tab.Item key={item.key} title={item.tab}>{item.content}</Tab.Item>)\n            }\n        </Tab>\n    </div>\n    , mountNode);\n","css":".next-tabs-content {\n    color: #333;\n    font-size: 12px;\n    padding: 12px;\n}\n"},"body":"\n````jsx\nimport { Tab } from '@alifd/next';\n\nconst tabs = [\n    { tab: 'Home', key: 0, content: 'This is home page' },\n    { tab: 'Document', key: 1, content: 'This is document page' },\n    { tab: 'API', key: 2, content: 'This is api page' }\n];\n\nReactDOM.render(\n    <div>\n        <div>Render all tab contents</div>\n        <Tab lazyLoad={false}>\n            {\n                tabs.map(item => <Tab.Item key={item.key} title={item.tab}>{item.content}</Tab.Item>)\n            }\n        </Tab>\n\n        <div>Unmount inactive tabs</div>\n        <Tab unmountInactiveTabs>\n            {\n                tabs.map(item => <Tab.Item key={item.key} title={item.tab}>{item.content}</Tab.Item>)\n            }\n        </Tab>\n    </div>\n    , mountNode);\n````\n\n````css\n.next-tabs-content {\n    color: #333;\n    font-size: 12px;\n    padding: 12px;\n}\n````","html":"<script>(function(){'use strict';\n\nvar _next = require('@alifd/next');\n\nvar tabs = [{ tab: 'Home', key: 0, content: 'This is home page' }, { tab: 'Document', key: 1, content: 'This is document page' }, { tab: 'API', key: 2, content: 'This is api page' }];\n\nReactDOM.render(React.createElement(\n    'div',\n    null,\n    React.createElement(\n        'div',\n        null,\n        'Render all tab contents'\n    ),\n    React.createElement(\n        _next.Tab,\n        { lazyLoad: false },\n        tabs.map(function (item) {\n            return React.createElement(\n                _next.Tab.Item,\n                { key: item.key, title: item.tab },\n                item.content\n            );\n        })\n    ),\n    React.createElement(\n        'div',\n        null,\n        'Unmount inactive tabs'\n    ),\n    React.createElement(\n        _next.Tab,\n        { unmountInactiveTabs: true },\n        tabs.map(function (item) {\n            return React.createElement(\n                _next.Tab.Item,\n                { key: item.key, title: item.tab },\n                item.content\n            );\n        })\n    )\n), mountNode);})()</script><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> Tab <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next'</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> tabs <span class=\"token operator\">=</span> <span class=\"token punctuation\">[</span>\n    <span class=\"token punctuation\">{</span> tab<span class=\"token operator\">:</span> <span class=\"token string\">'Home'</span><span class=\"token punctuation\">,</span> key<span class=\"token operator\">:</span> <span class=\"token number\">0</span><span class=\"token punctuation\">,</span> content<span class=\"token operator\">:</span> <span class=\"token string\">'This is home page'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    <span class=\"token punctuation\">{</span> tab<span class=\"token operator\">:</span> <span class=\"token string\">'Document'</span><span class=\"token punctuation\">,</span> key<span class=\"token operator\">:</span> <span class=\"token number\">1</span><span class=\"token punctuation\">,</span> content<span class=\"token operator\">:</span> <span class=\"token string\">'This is document page'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    <span class=\"token punctuation\">{</span> tab<span class=\"token operator\">:</span> <span class=\"token string\">'API'</span><span class=\"token punctuation\">,</span> key<span class=\"token operator\">:</span> <span class=\"token number\">2</span><span class=\"token punctuation\">,</span> content<span class=\"token operator\">:</span> <span class=\"token string\">'This is api page'</span> <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n\nReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span>\n    <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Render all tab contents</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Tab</span></span> <span class=\"token attr-name\">lazyLoad</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token boolean\">false</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token punctuation\">{</span>\n                tabs<span class=\"token punctuation\">.</span><span class=\"token function\">map</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">item</span> <span class=\"token operator\">=></span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Tab.Item</span></span> <span class=\"token attr-name\">key</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">.</span>key<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">title</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">.</span>tab<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">.</span>content<span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Tab.Item</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span>\n            <span class=\"token punctuation\">}</span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Tab</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Unmount inactive tabs</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Tab</span></span> <span class=\"token attr-name\">unmountInactiveTabs</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token punctuation\">{</span>\n                tabs<span class=\"token punctuation\">.</span><span class=\"token function\">map</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">item</span> <span class=\"token operator\">=></span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Tab.Item</span></span> <span class=\"token attr-name\">key</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">.</span>key<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">title</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">.</span>tab<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">.</span>content<span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Tab.Item</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span>\n            <span class=\"token punctuation\">}</span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Tab</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span>\n    <span class=\"token punctuation\">,</span> mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><style type=\"text/css\">.next-tabs-content {\n    color: #333;\n    font-size: 12px;\n    padding: 12px;\n}</style><div class=\"highlight\"><pre class=\"language-css\"><code class=\"language-css\"><span class=\"token selector\">.next-tabs-content</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">color</span><span class=\"token punctuation\">:</span> #333<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">font-size</span><span class=\"token punctuation\">:</span> 12px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">padding</span><span class=\"token punctuation\">:</span> 12px<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span></code></pre></div>"}